@@ -22,57 +22,58 @@
 #
 # gen.filters.rules/_HasNoteBase.py
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ...const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from . import Rule
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "Objects having notes"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasNoteBase(Rule):
     """Objects having notes"""
 
-    labels      = [  _('Number of instances:'), _('Number must be:')]
-    name        = 'Object with notes'
+    labels = [_("Number of instances:"), _("Number must be:")]
+    name = "Object with notes"
     description = "Matches objects that have a certain number of notes"
-    category    = _('General filters')
+    category = _("General filters")
 
-    def __init__(self, arg, use_regex=False):
+    def __init__(self, arg, use_regex=False, use_case=False):
         # Upgrade from pre 3.1 HasNote filter, use defaults that correspond
         # Previous filter had 0 arguments
         if len(arg) == 0:
-            Rule.__init__(self, ["0", 'greater than'], use_regex)
+            Rule.__init__(self, ["0", "greater than"], use_regex, use_case)
         else:
-            Rule.__init__(self, arg, use_regex)
+            Rule.__init__(self, arg, use_regex, use_case)
 
-    def prepare(self, db):
+    def prepare(self, db, user):
         # things we want to do just once, not for every handle
-        if  self.list[1] == 'less than':
+        if self.list[1] == "less than":
             self.count_type = 0
-        elif self.list[1] == 'greater than':
+        elif self.list[1] == "greater than":
             self.count_type = 2
         else:
-            self.count_type = 1 # "equal to"
+            self.count_type = 1  # "equal to"
 
         self.userSelectedCount = int(self.list[0])
 
-
     def apply(self, db, obj):
-        count = len( obj.get_note_list())
-        if self.count_type == 0:     # "less than"
+        count = len(obj.get_note_list())
+        if self.count_type == 0:  # "less than"
             return count < self.userSelectedCount
-        elif self.count_type == 2:   # "greater than"
+        elif self.count_type == 2:  # "greater than"
             return count > self.userSelectedCount
         # "equal to"
         return count == self.userSelectedCount
