@@ -20,26 +20,28 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hassourcecountbase import HasSourceCountBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "People having sources"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasSourceCount(HasSourceCountBase):
     """Events with sources"""
 
-    name = _('Events with <count> sources')
+    name = _("Events with <count> sources")
     description = _("Matches events with a certain number of sources connected to it")
