@@ -18,33 +18,37 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ..person import RegExpName
 from ._memberbase import father_base
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # RegExpFatherName
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class RegExpFatherName(RegExpName):
     """Rule that checks for full or partial name matches"""
 
-    name        = _('Families with father matching the <regex_name>')
-    description = _("Matches families whose father has a name "
-                    "matching a specified regular expression")
-    category    = _('Father filters')
+    name = _("Families with father matching the <regex_name>")
+    description = _(
+        "Matches families whose father has a name "
+        "matching a specified regular expression"
+    )
+    category = _("Father filters")
     base_class = RegExpName
     apply = father_base
