@@ -18,28 +18,30 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hasnotesubstrbase import HasNoteSubstrBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "Media having notes that contain a substring"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasNoteMatchingSubstringOf(HasNoteSubstrBase):
     """Media having notes containing <substring>"""
 
-    name        = _('Media objects having notes containing <substring>')
-    description = _("Matches media objects whose notes contain text "
-                    "matching a substring")
-
+    name = _("Media objects having notes containing <substring>")
+    description = _(
+        "Matches media objects whose notes contain text " "matching a substring"
+    )
