@@ -18,27 +18,29 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._isprivate import IsPrivate
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "People marked private"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PeoplePrivate(IsPrivate):
     """People marked private"""
 
-    name        = _('People marked private')
+    name = _("People marked private")
     description = _("Matches people that are indicated as private")
-    category    = _('General filters')
+    category = _("General filters")
