@@ -18,32 +18,34 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .. import Rule
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "People with incomplete events"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PersonWithIncompleteEvent(Rule):
     """People with incomplete events"""
 
-    name        = _('People with incomplete events')
+    name = _("People with incomplete events")
     description = _("Matches people with missing date or place in an event")
-    category    = _('Event filters')
+    category = _("Event filters")
 
-    def apply(self,db,person):
+    def apply(self, db, person):
         for event_ref in person.get_event_ref_list():
             if event_ref:
                 event = db.get_event_from_handle(event_ref.ref)
