@@ -25,19 +25,19 @@
 Family object for Gramps.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # standard python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from warnings import warn
 import logging
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .primaryobj import PrimaryObject
 from .citationbase import CitationBase
 from .notebase import NoteBase
@@ -50,17 +50,20 @@ from .childref import ChildRef
 from .familyreltype import FamilyRelType
 from .const import IDENTICAL, EQUAL, DIFFERENT
 from ..const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
 LOG = logging.getLogger(".citation")
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # Family class
 #
-#-------------------------------------------------------------------------
-class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
-             PrimaryObject):
+# -------------------------------------------------------------------------
+class Family(
+    CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase, PrimaryObject
+):
     """
     The Family record is the Gramps in-memory representation of the
     relationships between people. It contains all the information
@@ -116,17 +119,23 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                   be considered persistent.
         :rtype: tuple
         """
-        return (self.handle, self.gramps_id, self.father_handle,
-                self.mother_handle,
-                [cr.serialize() for cr in self.child_ref_list],
-                self.type.serialize(),
-                [er.serialize() for er in self.event_ref_list],
-                MediaBase.serialize(self),
-                AttributeBase.serialize(self),
-                LdsOrdBase.serialize(self),
-                CitationBase.serialize(self),
-                NoteBase.serialize(self),
-                self.change, TagBase.serialize(self), self.private)
+        return (
+            self.handle,
+            self.gramps_id,
+            self.father_handle,
+            self.mother_handle,
+            [cr.serialize() for cr in self.child_ref_list],
+            self.type.serialize(),
+            [er.serialize() for er in self.event_ref_list],
+            MediaBase.serialize(self),
+            AttributeBase.serialize(self),
+            LdsOrdBase.serialize(self),
+            CitationBase.serialize(self),
+            NoteBase.serialize(self),
+            self.change,
+            TagBase.serialize(self),
+            self.private,
+        )
 
     @classmethod
     def get_schema(cls):
@@ -140,55 +149,68 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         from .ldsord import LdsOrd
         from .childref import ChildRef
         from .attribute import Attribute
+
         return {
             "type": "object",
             "title": _("Family"),
             "properties": {
                 "_class": {"enum": [cls.__name__]},
-                "handle": {"type": "string",
-                           "maxLength": 50,
-                           "title": _("Handle")},
-                "gramps_id": {"type": "string",
-                              "title": _("Gramps ID")},
-                "father_handle": {"type": ["string", "null"],
-                                  "maxLength": 50,
-                                  "title": _("Father")},
-                "mother_handle": {"type": ["string", "null"],
-                                  "maxLength": 50,
-                                  "title": _("Mother")},
-                "child_ref_list": {"type": "array",
-                                   "items": ChildRef.get_schema(),
-                                   "title": _("Children")},
+                "handle": {"type": "string", "maxLength": 50, "title": _("Handle")},
+                "gramps_id": {"type": "string", "title": _("Gramps ID")},
+                "father_handle": {
+                    "type": ["string", "null"],
+                    "maxLength": 50,
+                    "title": _("Father"),
+                },
+                "mother_handle": {
+                    "type": ["string", "null"],
+                    "maxLength": 50,
+                    "title": _("Mother"),
+                },
+                "child_ref_list": {
+                    "type": "array",
+                    "items": ChildRef.get_schema(),
+                    "title": _("Children"),
+                },
                 "type": FamilyRelType.get_schema(),
-                "event_ref_list": {"type": "array",
-                                   "items": EventRef.get_schema(),
-                                   "title": _("Events")},
-                "media_list": {"type": "array",
-                               "items": MediaRef.get_schema(),
-                               "title": _("Media")},
-                "attribute_list": {"type": "array",
-                                   "items": Attribute.get_schema(),
-                                   "title": _("Attributes")},
-                "lds_ord_list": {"type": "array",
-                                 "items": LdsOrd.get_schema(),
-                                 "title": _("LDS ordinances")},
-                "citation_list": {"type": "array",
-                                  "items": {"type": "string",
-                                            "maxLength": 50},
-                                  "title": _("Citations")},
-                "note_list": {"type": "array",
-                              "items": {"type": "string",
-                                        "maxLength": 50},
-                              "title": _("Notes")},
-                "change": {"type": "integer",
-                           "title": _("Last changed")},
-                "tag_list": {"type": "array",
-                             "items": {"type": "string",
-                                       "maxLength": 50},
-                             "title": _("Tags")},
-                "private": {"type": "boolean",
-                            "title": _("Private")}
-            }
+                "event_ref_list": {
+                    "type": "array",
+                    "items": EventRef.get_schema(),
+                    "title": _("Events"),
+                },
+                "media_list": {
+                    "type": "array",
+                    "items": MediaRef.get_schema(),
+                    "title": _("Media"),
+                },
+                "attribute_list": {
+                    "type": "array",
+                    "items": Attribute.get_schema(),
+                    "title": _("Attributes"),
+                },
+                "lds_ord_list": {
+                    "type": "array",
+                    "items": LdsOrd.get_schema(),
+                    "title": _("LDS ordinances"),
+                },
+                "citation_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Citations"),
+                },
+                "note_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Notes"),
+                },
+                "change": {"type": "integer", "title": _("Last changed")},
+                "tag_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Tags"),
+                },
+                "private": {"type": "boolean", "title": _("Private")},
+            },
         }
 
     def unserialize(self, data):
@@ -196,17 +218,28 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Convert the data held in a tuple created by the serialize method
         back into the data in a Family structure.
         """
-        (self.handle, self.gramps_id, self.father_handle, self.mother_handle,
-         child_ref_list, the_type, event_ref_list, media_list,
-         attribute_list, lds_seal_list, citation_list, note_list,
-         self.change, tag_list, self.private) = data
+        (
+            self.handle,
+            self.gramps_id,
+            self.father_handle,
+            self.mother_handle,
+            child_ref_list,
+            the_type,
+            event_ref_list,
+            media_list,
+            attribute_list,
+            lds_seal_list,
+            citation_list,
+            note_list,
+            self.change,
+            tag_list,
+            self.private,
+        ) = data
 
         self.type = FamilyRelType()
         self.type.unserialize(the_type)
-        self.event_ref_list = [EventRef().unserialize(er)
-                               for er in event_ref_list]
-        self.child_ref_list = [ChildRef().unserialize(cr)
-                               for cr in child_ref_list]
+        self.event_ref_list = [EventRef().unserialize(er) for er in event_ref_list]
+        self.child_ref_list = [ChildRef().unserialize(cr) for cr in child_ref_list]
         MediaBase.unserialize(self, media_list)
         AttributeBase.unserialize(self, attribute_list)
         CitationBase.unserialize(self, citation_list)
@@ -228,12 +261,14 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                   this object type.
         :rtype: bool
         """
-        if classname == 'Event':
+        if classname == "Event":
             return handle in [ref.ref for ref in self.event_ref_list]
-        elif classname == 'Person':
-            return handle in ([ref.ref for ref in self.child_ref_list]
-                              + [self.father_handle, self.mother_handle])
-        elif classname == 'Place':
+        elif classname == "Person":
+            return handle in (
+                [ref.ref for ref in self.child_ref_list]
+                + [self.father_handle, self.mother_handle]
+            )
+        elif classname == "Place":
             return handle in [x.place for x in self.lds_ord_list]
         return False
 
@@ -246,19 +281,21 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :param handle_list: The list of handles to be removed.
         :type handle_list: str
         """
-        if classname == 'Event':
-            new_list = [ref for ref in self.event_ref_list
-                        if ref.ref not in handle_list]
+        if classname == "Event":
+            new_list = [
+                ref for ref in self.event_ref_list if ref.ref not in handle_list
+            ]
             self.event_ref_list = new_list
-        elif classname == 'Person':
-            new_list = [ref for ref in self.child_ref_list
-                        if ref.ref not in handle_list]
+        elif classname == "Person":
+            new_list = [
+                ref for ref in self.child_ref_list if ref.ref not in handle_list
+            ]
             self.child_ref_list = new_list
             if self.father_handle in handle_list:
                 self.father_handle = None
             if self.mother_handle in handle_list:
                 self.mother_handle = None
-        elif classname == 'Place':
+        elif classname == "Place":
             for lds_ord in self.lds_ord_list:
                 if lds_ord.place in handle_list:
                     lds_ord.place = None
@@ -274,7 +311,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :param new_handle: The handle to replace the old one with.
         :type new_handle: str
         """
-        if classname == 'Event':
+        if classname == "Event":
             refs_list = [ref.ref for ref in self.event_ref_list]
             new_ref = None
             if new_handle in refs_list:
@@ -292,7 +329,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                             new_ref.merge(evt_ref)
                         self.event_ref_list.pop(idx)
                         refs_list.pop(idx)
-        elif classname == 'Person':
+        elif classname == "Person":
             refs_list = [ref.ref for ref in self.child_ref_list]
             new_ref = None
             if new_handle in refs_list:
@@ -314,7 +351,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                 self.father_handle = new_handle
             if self.mother_handle == old_handle:
                 self.mother_handle = new_handle
-        elif classname == 'Place':
+        elif classname == "Place":
             for lds_ord in self.lds_ord_list:
                 if lds_ord.place == old_handle:
                     lds_ord.place = new_handle
@@ -346,8 +383,13 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                   refer citations.
         :rtype: list
         """
-        check_list = self.media_list + self.attribute_list + \
-            self.lds_ord_list + self.child_ref_list + self.event_ref_list
+        check_list = (
+            self.media_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.child_ref_list
+            + self.event_ref_list
+        )
         return check_list
 
     def get_note_child_list(self):
@@ -358,9 +400,13 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                   refer notes.
         :rtype: list
         """
-        check_list = self.media_list + self.attribute_list + \
-            self.lds_ord_list + self.child_ref_list + \
-            self.event_ref_list
+        check_list = (
+            self.media_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.child_ref_list
+            + self.event_ref_list
+        )
         return check_list
 
     def get_referenced_handles(self):
@@ -371,12 +417,17 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :returns: List of (classname, handle) tuples for referenced objects.
         :rtype: list
         """
-        ret = self.get_referenced_note_handles() + \
-                self.get_referenced_citation_handles()
-        ret += [('Person', handle) for handle
-                in ([ref.ref for ref in self.child_ref_list] +
-                    [self.father_handle, self.mother_handle])
-                if handle]
+        ret = (
+            self.get_referenced_note_handles() + self.get_referenced_citation_handles()
+        )
+        ret += [
+            ("Person", handle)
+            for handle in (
+                [ref.ref for ref in self.child_ref_list]
+                + [self.father_handle, self.mother_handle]
+            )
+            if handle
+        ]
         ret += self.get_referenced_tag_handles()
         return ret
 
@@ -388,8 +439,13 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
-        return self.media_list + self.attribute_list + \
-            self.lds_ord_list + self.child_ref_list + self.event_ref_list
+        return (
+            self.media_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.child_ref_list
+            + self.event_ref_list
+        )
 
     def merge(self, acquisition):
         """
@@ -524,8 +580,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         """
         if not isinstance(child_ref, ChildRef):
             raise ValueError("expecting ChildRef instance")
-        new_list = [ref for ref in self.child_ref_list
-                    if ref.ref != child_ref.ref]
+        new_list = [ref for ref in self.child_ref_list if ref.ref != child_ref.ref]
         self.child_ref_list = new_list
 
     def remove_child_handle(self, child_handle):
@@ -539,8 +594,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                   in the list.
         :rtype: bool
         """
-        new_list = [ref for ref in self.child_ref_list
-                    if ref.ref != child_handle]
+        new_list = [ref for ref in self.child_ref_list if ref.ref != child_handle]
         self.child_ref_list = new_list
 
     def get_child_ref_list(self):
@@ -601,8 +655,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         self.event_ref_list.append(event_ref)
 
     def get_event_list(self):
-        warn("Use get_event_ref_list instead of get_event_list",
-             DeprecationWarning, 2)
+        warn("Use get_event_ref_list instead of get_event_list", DeprecationWarning, 2)
         # Wrapper for old API
         # remove when transitition done.
         event_handle_list = []
