@@ -22,12 +22,21 @@
 """
 NoteBase class for Gramps.
 """
+# -------------------------------------------------------------------------
+#
+# Python modules
+#
+# -------------------------------------------------------------------------
+import logging
 
-#-------------------------------------------------------------------------
+LOG = logging.getLogger(".note")
+
+
+# -------------------------------------------------------------------------
 #
 # NoteBase class
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class NoteBase:
     """
     Base class for storing notes.
@@ -36,6 +45,7 @@ class NoteBase:
     Internally, this class maintains a list of Note handles,
     as a note_list attribute of the NoteBase object.
     """
+
     def __init__(self, source=None):
         """
         Create a new NoteBase, copying from source if not None.
@@ -132,6 +142,28 @@ class NoteBase:
 
         return False
 
+    def remove_note_references(self, handle_list):
+        """
+        Remove the specified handles from the list of note handles, and all
+        secondary child objects.
+
+        :param citation_handle_list: The list of note handles to be removed
+        :type handle: list
+        """
+        LOG.debug(
+            "enter remove_note handle: %s self: %s note_list: %s",
+            handle_list,
+            self,
+            self.note_list,
+        )
+        for handle in handle_list:
+            if handle in self.note_list:
+                LOG.debug("remove handle %s from note_list %s", handle, self.note_list)
+                self.note_list.remove(handle)
+        LOG.debug("get_note_child_list %s", self.get_note_child_list())
+        for item in self.get_note_child_list():
+            item.remove_note_references(handle_list)
+
     def set_note_list(self, note_list):
         """
         Assign the passed list to be object's list of :class:`~.note.Note`
@@ -164,7 +196,7 @@ class NoteBase:
         :returns: List of (classname, handle) tuples for referenced objects.
         :rtype: list
         """
-        return [('Note', handle) for handle in self.note_list]
+        return [("Note", handle) for handle in self.note_list]
 
     def replace_note_references(self, old_handle, new_handle):
         """
