@@ -25,11 +25,11 @@
 Person object for Gramps.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .primaryobj import PrimaryObject
 from .citationbase import CitationBase
 from .notebase import NoteBase
@@ -47,15 +47,25 @@ from .eventroletype import EventRoleType
 from .attribute import Attribute
 from .const import IDENTICAL, EQUAL, DIFFERENT
 from ..const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # Person class
 #
-#-------------------------------------------------------------------------
-class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
-             AddressBase, UrlBase, LdsOrdBase, PrimaryObject):
+# -------------------------------------------------------------------------
+class Person(
+    CitationBase,
+    NoteBase,
+    AttributeBase,
+    MediaBase,
+    AddressBase,
+    UrlBase,
+    LdsOrdBase,
+    PrimaryObject,
+):
     """
     The Person record is the Gramps in-memory representation of an
     individual person. It contains all the information related to
@@ -73,6 +83,7 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
 
     """
 
+    OTHER = 3
     UNKNOWN = 2
     MALE = 1
     FEMALE = 0
@@ -133,28 +144,28 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         :rtype: tuple
         """
         return (
-            self.handle,                                         #  0
-            self.gramps_id,                                      #  1
-            self.__gender,                                       #  2
-            self.primary_name.serialize(),                       #  3
-            [name.serialize() for name in self.alternate_names], #  4
-            self.death_ref_index,                                #  5
-            self.birth_ref_index,                                #  6
-            [er.serialize() for er in self.event_ref_list],      #  7
-            self.family_list,                                    #  8
-            self.parent_family_list,                             #  9
-            MediaBase.serialize(self),                           # 10
-            AddressBase.serialize(self),                         # 11
-            AttributeBase.serialize(self),                       # 12
-            UrlBase.serialize(self),                             # 13
-            LdsOrdBase.serialize(self),                          # 14
-            CitationBase.serialize(self),                        # 15
-            NoteBase.serialize(self),                            # 16
-            self.change,                                         # 17
-            TagBase.serialize(self),                             # 18
-            self.private,                                        # 19
-            [pr.serialize() for pr in self.person_ref_list]      # 20
-            )
+            self.handle,  #  0
+            self.gramps_id,  #  1
+            self.__gender,  #  2
+            self.primary_name.serialize(),  #  3
+            [name.serialize() for name in self.alternate_names],  #  4
+            self.death_ref_index,  #  5
+            self.birth_ref_index,  #  6
+            [er.serialize() for er in self.event_ref_list],  #  7
+            self.family_list,  #  8
+            self.parent_family_list,  #  9
+            MediaBase.serialize(self),  # 10
+            AddressBase.serialize(self),  # 11
+            AttributeBase.serialize(self),  # 12
+            UrlBase.serialize(self),  # 13
+            LdsOrdBase.serialize(self),  # 14
+            CitationBase.serialize(self),  # 15
+            NoteBase.serialize(self),  # 16
+            self.change,  # 17
+            TagBase.serialize(self),  # 18
+            self.private,  # 19
+            [pr.serialize() for pr in self.person_ref_list],  # 20
+        )
 
     @classmethod
     def get_schema(cls):
@@ -168,74 +179,97 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         from .address import Address
         from .url import Url
         from .ldsord import LdsOrd
+
         return {
             "type": "object",
             "title": _("Person"),
             "properties": {
                 "_class": {"enum": [cls.__name__]},
-                "handle": {"type": "string",
-                           "maxLength": 50,
-                           "title": _("Handle")},
-                "gramps_id": {"type": "string",
-                              "title": _("Gramps ID")},
-                "gender": {"type": "integer",
-                           "minimum": 0,
-                           "maximum": 2,
-                           "title": _("Gender")},
+                "handle": {"type": "string", "maxLength": 50, "title": _("Handle")},
+                "gramps_id": {"type": "string", "title": _("Gramps ID")},
+                "gender": {
+                    "type": "integer",
+                    "minimum": 0,
+                    "maximum": 2,
+                    "title": _("Gender"),
+                },
                 "primary_name": Name.get_schema(),
-                "alternate_names": {"type": "array",
-                                    "items": Name.get_schema(),
-                                    "title": _("Alternate names")},
-                "death_ref_index": {"type": "integer",
-                                    "title": _("Death reference index")},
-                "birth_ref_index": {"type": "integer",
-                                    "title": _("Birth reference index")},
-                "event_ref_list": {"type": "array",
-                                   "items": EventRef.get_schema(),
-                                   "title": _("Event references")},
-                "family_list": {"type": "array",
-                                "items": {"type": "string",
-                                          "maxLength": 50},
-                                "title": _("Families")},
-                "parent_family_list": {"type": "array",
-                                       "items": {"type": "string",
-                                                 "maxLength": 50},
-                                       "title": _("Parent families")},
-                "media_list": {"type": "array",
-                               "items": MediaRef.get_schema(),
-                               "title": _("Media")},
-                "address_list": {"type": "array",
-                                 "items": Address.get_schema(),
-                                 "title": _("Addresses")},
-                "attribute_list": {"type": "array",
-                                   "items": Attribute.get_schema(),
-                                   "title": _("Attributes")},
-                "urls": {"type": "array",
-                         "items": Url.get_schema(),
-                         "title": _("Urls")},
-                "lds_ord_list": {"type": "array",
-                                 "items": LdsOrd.get_schema(),
-                                 "title": _("LDS ordinances")},
-                "citation_list": {"type": "array",
-                                  "items": {"type": "string",
-                                            "maxLength": 50},
-                                  "title": _("Citations")},
-                "note_list": {"type": "array",
-                              "items": {"type": "string",
-                                        "maxLength": 50},
-                              "title": _("Notes")},
-                "change": {"type": "integer",
-                           "title": _("Last changed")},
-                "tag_list": {"type": "array",
-                             "items": {"type": "string",
-                                       "maxLength": 50},
-                             "title": _("Tags")},
-                "private": {"type": "boolean",
-                            "title": _("Private")},
-                "person_ref_list": {"type": "array",
-                                    "items": PersonRef.get_schema(),
-                                    "title": _("Person references")}
-            }
+                "alternate_names": {
+                    "type": "array",
+                    "items": Name.get_schema(),
+                    "title": _("Alternate names"),
+                },
+                "death_ref_index": {
+                    "type": "integer",
+                    "title": _("Death reference index"),
+                },
+                "birth_ref_index": {
+                    "type": "integer",
+                    "title": _("Birth reference index"),
+                },
+                "event_ref_list": {
+                    "type": "array",
+                    "items": EventRef.get_schema(),
+                    "title": _("Event references"),
+                },
+                "family_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Families"),
+                },
+                "parent_family_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Parent families"),
+                },
+                "media_list": {
+                    "type": "array",
+                    "items": MediaRef.get_schema(),
+                    "title": _("Media"),
+                },
+                "address_list": {
+                    "type": "array",
+                    "items": Address.get_schema(),
+                    "title": _("Addresses"),
+                },
+                "attribute_list": {
+                    "type": "array",
+                    "items": Attribute.get_schema(),
+                    "title": _("Attributes"),
+                },
+                "urls": {
+                    "type": "array",
+                    "items": Url.get_schema(),
+                    "title": _("Urls"),
+                },
+                "lds_ord_list": {
+                    "type": "array",
+                    "items": LdsOrd.get_schema(),
+                    "title": _("LDS ordinances"),
+                },
+                "citation_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Citations"),
+                },
+                "note_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Notes"),
+                },
+                "change": {"type": "integer", "title": _("Last changed")},
+                "tag_list": {
+                    "type": "array",
+                    "items": {"type": "string", "maxLength": 50},
+                    "title": _("Tags"),
+                },
+                "private": {"type": "boolean", "title": _("Private")},
+                "person_ref_list": {
+                    "type": "array",
+                    "items": PersonRef.get_schema(),
+                    "title": _("Person references"),
+                },
+            },
         }
 
     def unserialize(self, data):
@@ -247,37 +281,35 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                      Person object
         :type data: tuple
         """
-        (self.handle,             #  0
-         self.gramps_id,          #  1
-         self.__gender,           #  2
-         primary_name,            #  3
-         alternate_names,         #  4
-         self.death_ref_index,    #  5
-         self.birth_ref_index,    #  6
-         event_ref_list,          #  7
-         self.family_list,        #  8
-         self.parent_family_list, #  9
-         media_list,              # 10
-         address_list,            # 11
-         attribute_list,          # 12
-         urls,                    # 13
-         lds_ord_list,            # 14
-         citation_list,           # 15
-         note_list,               # 16
-         self.change,             # 17
-         tag_list,                # 18
-         self.private,            # 19
-         person_ref_list,         # 20
+        (
+            self.handle,  #  0
+            self.gramps_id,  #  1
+            self.__gender,  #  2
+            primary_name,  #  3
+            alternate_names,  #  4
+            self.death_ref_index,  #  5
+            self.birth_ref_index,  #  6
+            event_ref_list,  #  7
+            self.family_list,  #  8
+            self.parent_family_list,  #  9
+            media_list,  # 10
+            address_list,  # 11
+            attribute_list,  # 12
+            urls,  # 13
+            lds_ord_list,  # 14
+            citation_list,  # 15
+            note_list,  # 16
+            self.change,  # 17
+            tag_list,  # 18
+            self.private,  # 19
+            person_ref_list,  # 20
         ) = data
 
         self.primary_name = Name()
         self.primary_name.unserialize(primary_name)
-        self.alternate_names = [Name().unserialize(name)
-                                for name in alternate_names]
-        self.event_ref_list = [EventRef().unserialize(er)
-                               for er in event_ref_list]
-        self.person_ref_list = [PersonRef().unserialize(pr)
-                                for pr in person_ref_list]
+        self.alternate_names = [Name().unserialize(name) for name in alternate_names]
+        self.event_ref_list = [EventRef().unserialize(er) for er in event_ref_list]
+        self.person_ref_list = [PersonRef().unserialize(pr) for pr in person_ref_list]
         MediaBase.unserialize(self, media_list)
         LdsOrdBase.unserialize(self, lds_ord_list)
         AddressBase.unserialize(self, address_list)
@@ -301,36 +333,41 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                   this object type.
         :rtype: bool
         """
-        if classname == 'Event':
+        if classname == "Event":
             return any(ref.ref == handle for ref in self.event_ref_list)
-        elif classname == 'Person':
+        elif classname == "Person":
             return any(ref.ref == handle for ref in self.person_ref_list)
-        elif classname == 'Family':
-            return any(ref == handle
-                       for ref in self.family_list + self.parent_family_list +
-                       [ordinance.famc for ordinance in self.lds_ord_list])
-        elif classname == 'Place':
-            return any(ordinance.place == handle
-                       for ordinance in self.lds_ord_list)
+        elif classname == "Family":
+            return any(
+                ref == handle
+                for ref in self.family_list
+                + self.parent_family_list
+                + [ordinance.famc for ordinance in self.lds_ord_list]
+            )
+        elif classname == "Place":
+            return any(ordinance.place == handle for ordinance in self.lds_ord_list)
         return False
 
     def _remove_handle_references(self, classname, handle_list):
-        if classname == 'Event':
+        if classname == "Event":
             # Keep a copy of the birth and death references
             birth_ref = self.get_birth_ref()
             death_ref = self.get_death_ref()
 
-            new_list = [ref for ref in self.event_ref_list
-                        if ref.ref not in handle_list]
+            new_list = [
+                ref for ref in self.event_ref_list if ref.ref not in handle_list
+            ]
             # If deleting removing the reference to the event
             # to which birth or death ref_index points, unset the index
-            if (self.birth_ref_index != -1
-                    and self.event_ref_list[self.birth_ref_index].ref
-                    in handle_list):
+            if (
+                self.birth_ref_index != -1
+                and self.event_ref_list[self.birth_ref_index].ref in handle_list
+            ):
                 self.set_birth_ref(None)
-            if (self.death_ref_index != -1
-                    and self.event_ref_list[self.death_ref_index].ref
-                    in handle_list):
+            if (
+                self.death_ref_index != -1
+                and self.event_ref_list[self.death_ref_index].ref in handle_list
+            ):
                 self.set_death_ref(None)
             self.event_ref_list = new_list
 
@@ -339,27 +376,32 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                 self.set_birth_ref(birth_ref)
             if self.death_ref_index != -1:
                 self.set_death_ref(death_ref)
-        elif classname == 'Person':
-            new_list = [ref for ref in self.person_ref_list
-                        if ref.ref not in handle_list]
+        elif classname == "Person":
+            new_list = [
+                ref for ref in self.person_ref_list if ref.ref not in handle_list
+            ]
             self.person_ref_list = new_list
-        elif classname == 'Family':
-            new_list = [handle for handle in self.family_list
-                        if handle not in handle_list]
+        elif classname == "Family":
+            new_list = [
+                handle for handle in self.family_list if handle not in handle_list
+            ]
             self.family_list = new_list
-            new_list = [handle for handle in self.parent_family_list
-                        if handle not in handle_list]
+            new_list = [
+                handle
+                for handle in self.parent_family_list
+                if handle not in handle_list
+            ]
             self.parent_family_list = new_list
             for ordinance in self.lds_ord_list:
                 if ordinance.famc in handle_list:
                     ordinance.famc = None
-        elif classname == 'Place':
+        elif classname == "Place":
             for ordinance in self.lds_ord_list:
                 if ordinance.place in handle_list:
                     ordinance.place = None
 
     def _replace_handle_reference(self, classname, old_handle, new_handle):
-        if classname == 'Event':
+        if classname == "Event":
             refs_list = [ref.ref for ref in self.event_ref_list]
             new_ref = None
             if new_handle in refs_list:
@@ -389,7 +431,7 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                             self.death_ref_index = -1
                             # death_ref_index should be recalculated which
                             # needs database access!
-        elif classname == 'Person':
+        elif classname == "Person":
             refs_list = [ref.ref for ref in self.person_ref_list]
             new_ref = None
             if new_handle in refs_list:
@@ -407,7 +449,7 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                             new_ref.merge(person_ref)
                         self.person_ref_list.pop(idx)
                         refs_list.pop(idx)
-        elif classname == 'Family':
+        elif classname == "Family":
             while old_handle in self.family_list:
                 ix = self.family_list.index(old_handle)
                 self.family_list[ix] = new_handle
@@ -418,13 +460,13 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
             while old_handle in handle_list:
                 ix = handle_list.index(old_handle)
                 self.lds_ord_list[ix].famc = new_handle
-                handle_list[ix] = ''
+                handle_list[ix] = ""
         elif classname == "Place":
             handle_list = [ordinance.place for ordinance in self.lds_ord_list]
             while old_handle in handle_list:
                 ix = handle_list.index(old_handle)
                 self.lds_ord_list[ix].place = new_handle
-                handle_list[ix] = ''
+                handle_list[ix] = ""
 
     def get_text_data_list(self):
         """
@@ -444,16 +486,17 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         """
         check_list = self.lds_ord_list
         add_list = [_f for _f in check_list if _f]
-        return ([self.primary_name] +
-                self.media_list +
-                self.alternate_names +
-                self.address_list +
-                self.attribute_list +
-                self.urls +
-                self.event_ref_list +
-                add_list +
-                self.person_ref_list
-               )
+        return (
+            [self.primary_name]
+            + self.media_list
+            + self.alternate_names
+            + self.address_list
+            + self.attribute_list
+            + self.urls
+            + self.event_ref_list
+            + add_list
+            + self.person_ref_list
+        )
 
     def get_citation_child_list(self):
         """
@@ -463,15 +506,16 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                   refer citations.
         :rtype: list
         """
-        return ([self.primary_name] +
-                self.media_list +
-                self.alternate_names +
-                self.address_list +
-                self.attribute_list +
-                self.lds_ord_list +
-                self.person_ref_list +
-                self.event_ref_list
-               )
+        return (
+            [self.primary_name]
+            + self.media_list
+            + self.alternate_names
+            + self.address_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.person_ref_list
+            + self.event_ref_list
+        )
 
     def get_note_child_list(self):
         """
@@ -481,15 +525,16 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                   refer notes.
         :rtype: list
         """
-        return ([self.primary_name] +
-                self.media_list +
-                self.alternate_names +
-                self.address_list +
-                self.attribute_list +
-                self.lds_ord_list +
-                self.person_ref_list +
-                self.event_ref_list
-               )
+        return (
+            [self.primary_name]
+            + self.media_list
+            + self.alternate_names
+            + self.address_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.person_ref_list
+            + self.event_ref_list
+        )
 
     def get_referenced_handles(self):
         """
@@ -499,12 +544,14 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         :returns: List of (classname, handle) tuples for referenced objects.
         :rtype: list
         """
-        return [('Family', handle) for handle in
-                (self.family_list + self.parent_family_list)] + (
-                    self.get_referenced_note_handles() +
-                    self.get_referenced_citation_handles() +
-                    self.get_referenced_tag_handles()
-                )
+        return [
+            ("Family", handle)
+            for handle in (self.family_list + self.parent_family_list)
+        ] + (
+            self.get_referenced_note_handles()
+            + self.get_referenced_citation_handles()
+            + self.get_referenced_tag_handles()
+        )
 
     def get_handle_referents(self):
         """
@@ -514,15 +561,16 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
-        return ([self.primary_name] +
-                self.media_list +
-                self.alternate_names +
-                self.address_list +
-                self.attribute_list +
-                self.lds_ord_list +
-                self.person_ref_list +
-                self.event_ref_list
-               )
+        return (
+            [self.primary_name]
+            + self.media_list
+            + self.alternate_names
+            + self.address_list
+            + self.attribute_list
+            + self.lds_ord_list
+            + self.person_ref_list
+            + self.event_ref_list
+        )
 
     def merge(self, acquisition):
         """
@@ -552,8 +600,12 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         self._merge_citation_list(acquisition)
         self._merge_tag_list(acquisition)
 
-        list(map(self.add_parent_family_handle,
-                 acquisition.get_parent_family_handle_list()))
+        list(
+            map(
+                self.add_parent_family_handle,
+                acquisition.get_parent_family_handle_list(),
+            )
+        )
         list(map(self.add_family_handle, acquisition.get_family_handle_list()))
 
     def set_primary_name(self, name):
@@ -633,7 +685,7 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         for attr in self.attribute_list:
             if int(attr.type) == AttributeType.NICKNAME:
                 return attr.get_value()
-        return ''
+        return ""
 
     def set_gender(self, gender):
         """
@@ -644,11 +696,12 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
 
                        - Person.MALE
                        - Person.FEMALE
+                       - Person.OTHER
                        - Person.UNKNOWN
         :type gender: int
         """
-        if gender not in (Person.MALE, Person.FEMALE, Person.UNKNOWN):
-            raise ValueError('Attempt to assign invalid gender')
+        if gender not in (Person.MALE, Person.FEMALE, Person.OTHER, Person.UNKNOWN):
+            raise ValueError("Attempt to assign invalid gender")
         self.__gender = gender
 
     def get_gender(self):
@@ -659,13 +712,15 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
 
                   - Person.MALE
                   - Person.FEMALE
+                  - Person.OTHER
                   - Person.UNKNOWN
         :rtype: int
         """
         return self.__gender
 
-    gender = property(get_gender, set_gender, None,
-                      'Returns or sets the gender of the person')
+    gender = property(
+        get_gender, set_gender, None, "Returns or sets the gender of the person"
+    )
 
     def set_birth_ref(self, event_ref):
         """
@@ -687,10 +742,10 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         # check whether we already have this ref in the list
         for self.birth_ref_index, ref in enumerate(self.event_ref_list):
             if event_ref.is_equal(ref):
-                return    # Note: self.birth_ref_index already set
+                return  # Note: self.birth_ref_index already set
 
         self.event_ref_list.append(event_ref)
-        self.birth_ref_index = len(self.event_ref_list)-1
+        self.birth_ref_index = len(self.event_ref_list) - 1
 
     def set_death_ref(self, event_ref):
         """
@@ -712,10 +767,10 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
         # check whether we already have this ref in the list
         for self.death_ref_index, ref in enumerate(self.event_ref_list):
             if event_ref.is_equal(ref):
-                return    # Note: self.death_ref_index already set
+                return  # Note: self.death_ref_index already set
 
         self.event_ref_list.append(event_ref)
-        self.death_ref_index = len(self.event_ref_list)-1
+        self.death_ref_index = len(self.event_ref_list) - 1
 
     def get_birth_ref(self):
         """
@@ -791,9 +846,11 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                   associated with the Person instance.
         :rtype: generator
         """
-        return (ref for ref in self.event_ref_list
-                if ref.get_role() == EventRoleType.PRIMARY
-               )
+        return (
+            ref
+            for ref in self.event_ref_list
+            if ref.get_role() == EventRoleType.PRIMARY
+        )
 
     def set_event_ref_list(self, event_ref_list):
         """
@@ -825,11 +882,9 @@ class Person(CitationBase, NoteBase, AttributeBase, MediaBase,
                     break
             else:
                 self.event_ref_list.append(addendum)
-                if (self.birth_ref_index == -1 and
-                        idx == acquisition.birth_ref_index):
+                if self.birth_ref_index == -1 and idx == acquisition.birth_ref_index:
                     self.birth_ref_index = len(self.event_ref_list) - 1
-                if (self.death_ref_index == -1 and
-                        idx == acquisition.death_ref_index):
+                if self.death_ref_index == -1 and idx == acquisition.death_ref_index:
                     self.death_ref_index = len(self.event_ref_list) - 1
 
     def add_family_handle(self, family_handle):
