@@ -9,7 +9,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -19,27 +19,32 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import types
 import logging
+
 LOG = logging.getLogger(".Gramplets")
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
+from ...gui.dbguielement import DbGUIElement
 from ..const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-class Gramplet(object):
+
+class Gramplet:
     """
     Base class for non-graphical gramplet code.
     """
+
     def __init__(self, gui, nav_group=0):
         """
         Internal constructor for non-graphical gramplets.
@@ -56,37 +61,35 @@ class Gramplet(object):
         self._signal = {}
         self.option_order = []
         # links to each other:
-        self.gui = gui   # plugin gramplet has link to gui
-        gui.pui = self   # gui has link to plugin ui
+        self.gui = gui  # plugin gramplet has link to gui
+        gui.pui = self  # gui has link to plugin ui
         self.nav_group = nav_group
         self.dbstate = gui.dbstate
         self.uistate = gui.uistate
         self.init()
         self.on_load()
         self.build_options()
-        self.connect(self.dbstate, "database-changed", self._db_changed)
-        self.connect(self.gui.textview, "button-press-event", 
-                     self.gui.on_button_press) 
-        self.connect(self.gui.textview, "motion-notify-event", 
-                     self.gui.on_motion)
-        self.connect_signal('Person', self._active_changed)
-        
+        self.dbstate.connect("database-changed", self._db_changed)
+        self.dbstate.connect("no-database", self._no_db)
+        self.gui.textview.connect("button-press-event", self.gui.on_button_press)
+        self.gui.textview.connect("motion-notify-event", self.gui.on_motion)
         self._db_changed(self.dbstate.db)
-        active_person = self.get_active('Person')
-        if active_person: # already changed
+        active_person = self.get_active("Person")
+        if active_person:  # already changed
             self._active_changed(active_person)
         self.post_init()
 
     def connect_signal(self, nav_type, method):
         """
         Connect the given method to the active-changed signal for the
-        navigation type requested. 
+        navigation type requested.
         """
         self.uistate.register(self.dbstate, nav_type, self.nav_group)
         history = self.uistate.get_history(nav_type, self.nav_group)
+        # print('History: nave-type = %s' % nav_type)
         self.connect(history, "active-changed", method)
 
-    def init(self): # once, constructor
+    def init(self):  # once, constructor
         """
         External constructor for developers to put their initialization
         code. Designed to be overridden.
@@ -103,7 +106,7 @@ class Gramplet(object):
         """
         pass
 
-    def main(self): # return false finishes
+    def main(self):  # return false finishes
         """
         The main place for the gramplet's code. This is a generator.
         Generator which will be run in the background, through :meth:`update`.
@@ -133,11 +136,11 @@ class Gramplet(object):
     def get_active_object(self, nav_type):
         """
         Return the object of the active handle for the given navigation type.
-        Assumes nav_type is one of the codes of Db.get_by_name.
         """
         handle = self.uistate.get_active(nav_type, self.nav_group)
-        if nav_type in self.dbstate.db.get_table_names() and handle:
-            return self.dbstate.db.get_from_name_and_handle(nav_type, handle)
+        handle_func = getattr(self.dbstate.db, "get_%s_from_handle" % nav_type.lower())
+        if handle:
+            return handle_func(handle)
         return None
 
     def set_active(self, nav_type, handle):
@@ -161,7 +164,7 @@ class Gramplet(object):
 
     def db_changed(self):
         """
-        Method executed when the database is changed. 
+        Method executed when the database is changed.
         """
         pass
 
@@ -184,7 +187,7 @@ class Gramplet(object):
         Returns the current text of the textview.
         """
         return self.gui.get_text()
-        
+
     def insert_text(self, text):
         """
         Insert the given text in the textview at the cursor.
@@ -202,11 +205,11 @@ class Gramplet(object):
         Clear all of the text from the textview.
         """
         self.gui.clear_text()
-        
-    def set_text(self, text, scroll_to='start'):
+
+    def set_text(self, text, scroll_to="start"):
         """
         Clear and set the text to the given text. Additionally, move the
-        cursor to the position given. Positions are: 
+        cursor to the position given. Positions are:
 
             ========  =======================================
             Position  Description
@@ -221,7 +224,7 @@ class Gramplet(object):
     def append_text(self, text, scroll_to="end"):
         """
         Append the text to the textview. Additionally, move the
-        cursor to the position given. Positions are: 
+        cursor to the position given. Positions are:
 
             ========  =======================================
             Position  Description
@@ -245,6 +248,7 @@ class Gramplet(object):
         """
         textview = self.gui.textview
         from gi.repository import Gtk
+
         # Gtk.WrapMode.NONE, Gtk.WrapMode.CHAR, Gtk.WrapMode.WORD or Gtk.WrapMode.WORD_CHAR.
         if value in [True, 1]:
             textview.set_wrap_mode(Gtk.WrapMode.WORD)
@@ -256,8 +260,8 @@ class Gramplet(object):
             textview.set_wrap_mode(Gtk.WrapMode.WORD_CHAR)
         else:
             raise ValueError(
-                    "Unknown wrap mode: '%s': use 0,1,'char' or 'word char')"
-                        % value)
+                "Unknown wrap mode: '%s': use 0,1,'char' or 'word char')" % value
+            )
 
     def no_wrap(self):
         """
@@ -276,7 +280,7 @@ class Gramplet(object):
         if len(self.gui.data) >= pos + 1:
             text = self.gui.data[pos]
             text = text.replace("\\n", chr(10))
-            self.set_text(text, 'end')
+            self.set_text(text, "end")
 
     def save_text_to_data(self):
         """
@@ -290,31 +294,24 @@ class Gramplet(object):
         """
         The main interface for running the :meth:`main` method.
         """
-        from gi.repository import GObject, GLib
-        if ((not self.active or 
-             self.gui.gstate in ["closed", "minimized"] or 
-             not self.dbstate.open) and 
-            not self.gui.force_update): 
+        from gi.repository import GLib
+
+        if (not self.active) and not self.gui.force_update:
             self.dirty = True
-            if self.dbstate.open:
-                #print "  %s is not active" % self.gui.gname
+            if self.dbstate.is_open():
+                # print "  %s is not active" % self.gui.gname
                 self.update_has_data()
             else:
                 self.set_has_data(False)
             return
-        #print "     %s is UPDATING" % self.gui.gname
+        # print "     %s is UPDATING" % self.gui.gname
         self.dirty = False
         LOG.debug("gramplet updater: %s: running" % self.gui.title)
         if self._idle_id != 0:
             self.interrupt()
         self._generator = self.main()
         self._pause = False
-        if GObject.pygobject_version < (3,16,0):
-            self._idle_id = GLib.idle_add(self._updater, 
-                                         priority=GObject.PRIORITY_LOW - 10)
-        else:
-            self._idle_id = GLib.idle_add(self._updater, 
-                                         priority=GLib.PRIORITY_LOW - 10)
+        self._idle_id = GLib.idle_add(self._updater, priority=GLib.PRIORITY_LOW - 10)
 
     def _updater(self):
         """
@@ -325,8 +322,6 @@ class Gramplet(object):
             self._idle_id = 0
             LOG.debug("gramplet updater: %s : One time, done!" % self.gui.title)
             return False
-        # FIXME: find out why Data Entry has this error, or just ignore it
-        import bsddb3 as bsddb
         try:
             retval = next(self._generator)
             if not retval:
@@ -334,26 +329,23 @@ class Gramplet(object):
             if self._pause:
                 LOG.debug("gramplet updater: %s: return False" % self.gui.title)
                 return False
-            LOG.debug("gramplet updater: %s: return %s" % 
-                      (self.gui.title, retval))
+            LOG.debug("gramplet updater: %s: return %s" % (self.gui.title, retval))
             return retval
-        except bsddb.db.DBCursorClosedError:
-            # not sure why---caused by Data Entry Gramplet
-            LOG.warn("bsddb.db.DBCursorClosedError in: %s" % self.gui.title)
-            return False
         except StopIteration:
             self._idle_id = 0
             self._generator.close()
-            LOG.debug("gramplet updater: %s: Done!"  % self.gui.title)
+            LOG.debug("gramplet updater: %s: Done!" % self.gui.title)
             return False
         except Exception as e:
             import traceback
-            LOG.warn("Gramplet gave an error: %s" % self.gui.title)
+
+            LOG.warning("Gramplet gave an error: %s" % self.gui.title)
             traceback.print_exc()
             print("Continuing after gramplet error...")
             self._idle_id = 0
-            self.uistate.push_message(self.dbstate,
-                _("Gramplet %s caused an error") % self.gui.title)
+            self.uistate.push_message(
+                self.dbstate, _("Gramplet %s caused an error") % self.gui.title
+            )
             return False
 
     def pause(self, *args):
@@ -366,14 +358,10 @@ class Gramplet(object):
         """
         Resume the :meth:`main` method that has previously paused.
         """
-        from gi.repository import GObject, GLib
+        from gi.repository import GLib
+
         self._pause = False
-        if GObject.pygobject_version < (3,16,0):
-            self._idle_id = GLib.idle_add(self._updater, 
-                                         priority=GObject.PRIORITY_LOW - 10)
-        else:
-            self._idle_id = GLib.idle_add(self._updater, 
-                                         priority=GLib.PRIORITY_LOW - 10)
+        self._idle_id = GLib.idle_add(self._updater, priority=GLib.PRIORITY_LOW - 10)
 
     def update_all(self, *args):
         """
@@ -390,6 +378,7 @@ class Gramplet(object):
         Force the generator to stop running.
         """
         from gi.repository import GLib
+
         self._pause = True
         if self._idle_id != 0:
             GLib.source_remove(self._idle_id)
@@ -400,11 +389,30 @@ class Gramplet(object):
         Internal method for handling items that should happen when the
         database changes. This will push a message to the GUI status bar.
         """
+        if self.dbstate.db.is_open():
+            self.disconnect_all()  # clear the old signals from old db
         self.dbstate.db = db
         self.gui.dbstate.db = db
-        self.db_changed()
+        if db.is_open():
+            # the following prevents connecting to every Gramplet, and still
+            # allows Person Gramplets to be informed of active-changed
+            # Some Gramplets .gpr files don't have navtypes set, thus the
+            # hasattr
+            if hasattr(self.gui, "navtypes") and "Person" in self.gui.navtypes:
+                self.connect_signal("Person", self._active_changed)
+            self.db_changed()
+        # Some Gramplets use DbGUIElement; and DbGUIElement needs to know if
+        # db is changed.  However, at initialization, DbGUIElement is not yet
+        # initialized when _db_changed is called, thus the test for callman
+        if hasattr(self, "callman") and isinstance(self, DbGUIElement):
+            # get DbGUIElement informed if in use
+            self._change_db(db)  # DbGUIElement method
+
         self.update()
 
+    def _no_db(self):
+        self.disconnect_all()  # clear the old signals
+
     def get_option_widget(self, label):
         """
         Retrieve an option's widget by its label text.
@@ -421,9 +429,7 @@ class Gramplet(object):
         """
         Add an option to the GUI gramplet.
         """
-        from gramps.gui.plug import make_gui_option
-        widget, label = make_gui_option(
-            option, self.dbstate, self.uistate, self.track)
+        widget, label = self.gui.add_gui_option(option)
         self.option_dict.update({option.get_label(): [widget, option]})
         self.option_order.append(option.get_label())
 
@@ -445,11 +451,21 @@ class Gramplet(object):
 
     def disconnect(self, signal):
         if signal in self._signal:
-            for (id, signal_obj) in self._signal[signal]:
+            for id, signal_obj in self._signal[signal]:
                 signal_obj.disconnect(id)
+            self._signal[signal] = []
         else:
             raise AttributeError("unknown signal: '%s'" % signal)
-        
+
+    def disconnect_all(self):
+        """
+        Used to disconnect all the signals for this specific gramplet
+        """
+        for signal in self._signal:
+            for sig_id, signal_obj in self._signal[signal]:
+                signal_obj.disconnect(sig_id)
+            self._signal[signal] = []
+
     def hidden_widgets(self):
         """
         A list of widgets to keep hidden. Needed because Gramps uses
@@ -470,3 +486,13 @@ class Gramplet(object):
         By default, assume that the gramplet has data.
         """
         self.set_has_data(True)
+
+    def set_orientation(self, orientation):
+        """
+        Called when the gramplet orientation changes. A gramplet may override
+        this if it has a preferred horizontal and vertical layout.
+
+        :param orientation: A Gtk.Orientation (VERTCIAL or HORIZONTAL)
+        :type orientation: int
+        """
+        pass
