@@ -23,30 +23,44 @@
 """
 Contain and organize bibliographic information.
 """
+
+# -------------------------------------------------------------------------
+#
+# Standard python modules
+#
+# -------------------------------------------------------------------------
 import string
 import math
+
+# -------------------------------------------------------------------------
+#
+# Gramps modules
+#
+# -------------------------------------------------------------------------
 from ...lib.citation import Citation as lib_Citation
 
-class Citation(object):
+
+class Citation:
     """
     Store information about a citation and all of its references.
     """
+
     def __init__(self):
         """
         Initialize members.
         """
         self.__src_handle = None
         self.__ref_list = []
-          
+
     def get_source_handle(self):
         """
         Provide the handle to the source that this citation is for.
-        
+
         :return: Source Handle
         :rtype: handle
         """
         return self.__src_handle
-    
+
     def set_source_handle(self, handle):
         """
         Set the handle for the source that this citation is for.
@@ -55,7 +69,7 @@ class Citation(object):
         :type handle: handle
         """
         self.__src_handle = handle
-        
+
     def get_ref_list(self):
         """
         List all the references to this citation.
@@ -75,35 +89,38 @@ class Citation(object):
         :return: The key of the added reference among all the references.
         :rtype: char
         """
-        letter_count = len(string.ascii_lowercase)
+        letters = string.ascii_lowercase  # or (e.g.) "abcdef" for testing
+        letter_count = len(letters)
         ref_count = len(self.__ref_list)
         x_ref_count = ref_count
         # Return "a" for ref_count = 0, otherwise log(0) does not work
         if ref_count == 0:
-            self.__ref_list.append(("a", source_ref))
-            return "a"
-        last_letter = string.ascii_lowercase[ ref_count % letter_count ]
+            self.__ref_list.append((letters[0], source_ref))
+            return letters[0]
+        last_letter = letters[ref_count % letter_count]
         key = ""
         # Calculate prek number of digits.
-        number_of_letters = int(math.log(float(ref_count), float(letter_count)))+1
+        number_of_letters = 1 + int(math.log(float(ref_count), float(letter_count)))
         # Exclude index for number_of_letters-1
-        for n in range(1, number_of_letters-1):
-            ref_count -= pow(letter_count, n) 
+        for n in range(1, number_of_letters - 1):
+            ref_count -= pow(letter_count, n)
         # Adjust number_of_letters for new index
-        number_of_letters = int(math.log(float(ref_count), float(letter_count))) +1
+        number_of_letters = 1 + int(math.log(float(ref_count), float(letter_count)))
         for n in range(1, number_of_letters):
-            x_ref_count -= pow(letter_count, n) 
+            x_ref_count -= pow(letter_count, n)
         for letter in range(1, number_of_letters):
-            index = x_ref_count // pow(letter_count, letter)  % letter_count
-            key += string.ascii_lowercase[ index ]
+            index = x_ref_count // pow(letter_count, letter) % letter_count
+            key += letters[index]
         key = key + last_letter
         self.__ref_list.append((key, source_ref))
         return key
 
-class Bibliography(object):
+
+class Bibliography:
     """
     Store and organize multiple citations into a bibliography.
     """
+
     MODE_DATE = 2**0
     MODE_PAGE = 2**1
     MODE_CONF = 2**2
@@ -117,7 +134,7 @@ class Bibliography(object):
         citations (citations). Duplicate entries will not be added. To change
         what is considered duplicate, you can tell the bibliography what source
         ref information you are interested in by passing in the mode.
-        
+
         Possible modes include:
 
         - MODE_DATE
@@ -126,7 +143,7 @@ class Bibliography(object):
         - MODE_NOTE
         - MODE_MEDIA
         - MODE_ALL
-        
+
         If you only care about pages, set "mode=MODE_PAGE".
         If you only care about dates and pages, set "mode=MODE_DATE|MODE_PAGE".
         If you care about everything, set "mode=MODE_ALL".
@@ -142,13 +159,13 @@ class Bibliography(object):
 
         :param citation: Citation object
         :type citation: :class:`~.citation.Citation`
-        :return: A tuple containing the index of the source among all the 
+        :return: A tuple containing the index of the source among all the
                  sources and the key of the reference among all the references.
                  If there is no reference information, the second element will
                  be None.
         :rtype: (int,char) or (int,None)
-        
-        .. note:: 
+
+        .. note::
             Within this file, the name 'citation' is used both for
             gen.lib.Citation, and for _bibliography.Citation. It is not clear
             how best to rename the concepts in this file to avoid the clash,
@@ -167,7 +184,7 @@ class Bibliography(object):
                 citation_found = True
                 break
             cindex += 1
-            
+
         if not citation_found:
             citation = Citation()
             citation.set_source_handle(source_handle)
@@ -177,13 +194,13 @@ class Bibliography(object):
         if self.__sref_has_info(lib_citation):
             for key, ref in citation.get_ref_list():
                 if self.__srefs_are_equal(ref, lib_citation):
-                    # if a reference like this already exists, don't add 
+                    # if a reference like this already exists, don't add
                     # another one
                     return (cindex, key)
             rkey = citation.add_reference(lib_citation)
-        
+
         return (cindex, rkey)
-    
+
     def get_citation_count(self):
         """
         Report the number of citations in this bibliography.
@@ -192,7 +209,7 @@ class Bibliography(object):
         :rtype: int
         """
         return len(self.__citation_list)
-    
+
     def get_citation_list(self):
         """
         Return a list containing all the citations in this bibliography.
@@ -204,33 +221,32 @@ class Bibliography(object):
 
     def __sref_has_info(self, source_ref):
         """
-        Determine if this source_ref has any useful information based on the 
+        Determine if this source_ref has any useful information based on the
         current mode.
         """
-        if ( self.mode & self.MODE_PAGE ) == self.MODE_PAGE:
+        if (self.mode & self.MODE_PAGE) == self.MODE_PAGE:
             if source_ref.get_page() != "":
                 return True
-        if ( self.mode & self.MODE_DATE ) == self.MODE_DATE:
+        if (self.mode & self.MODE_DATE) == self.MODE_DATE:
             date = source_ref.get_date_object()
             if date is not None and not date.is_empty():
                 return True
-        if ( self.mode & self.MODE_CONF ) == self.MODE_CONF:
+        if (self.mode & self.MODE_CONF) == self.MODE_CONF:
             confidence = source_ref.get_confidence_level()
-            if confidence is not None and confidence != \
-                                        lib_Citation.CONF_NORMAL:
+            if confidence is not None and confidence != lib_Citation.CONF_NORMAL:
                 return True
-        if ( self.mode & self.MODE_NOTE ) == self.MODE_NOTE:
+        if (self.mode & self.MODE_NOTE) == self.MODE_NOTE:
             if len(source_ref.get_note_list()) != 0:
                 return True
-        if ( self.mode & self.MODE_MEDIA ) == self.MODE_MEDIA:
+        if (self.mode & self.MODE_MEDIA) == self.MODE_MEDIA:
             if len(source_ref.get_media_list()) != 0:
                 return True
         # Can't find anything interesting.
         return False
-        
+
     def __srefs_are_equal(self, source_ref1, source_ref2):
         """
-        Determine if two source references are equal based on the 
+        Determine if two source references are equal based on the
         current mode.
         """
         # The criterion for equality (in mode==MODE_ALL) is changed for
@@ -244,20 +260,20 @@ class Bibliography(object):
         # are intended to represent the same citation.
         if self.mode == self.MODE_ALL:
             return source_ref1.handle == source_ref2.handle
-        if ( self.mode & self.MODE_PAGE ) == self.MODE_PAGE:
+        if (self.mode & self.MODE_PAGE) == self.MODE_PAGE:
             if source_ref1.get_page() != source_ref2.get_page():
                 return False
-        if ( self.mode & self.MODE_DATE ) == self.MODE_DATE:
+        if (self.mode & self.MODE_DATE) == self.MODE_DATE:
             date1 = source_ref1.get_date_object()
             date2 = source_ref2.get_date_object()
             if not date1.is_equal(date2):
                 return False
-        if ( self.mode & self.MODE_CONF ) == self.MODE_CONF:
+        if (self.mode & self.MODE_CONF) == self.MODE_CONF:
             conf1 = source_ref1.get_confidence_level()
             conf2 = source_ref2.get_confidence_level()
             if conf1 != conf2:
                 return False
-        if ( self.mode & self.MODE_NOTE ) == self.MODE_NOTE:
+        if (self.mode & self.MODE_NOTE) == self.MODE_NOTE:
             nl1 = source_ref1.get_note_list()
             nl2 = source_ref2.get_note_list()
             if len(nl1) != len(nl2):
@@ -265,7 +281,7 @@ class Bibliography(object):
             for notehandle in nl1:
                 if notehandle not in nl2:
                     return False
-        if ( self.mode & self.MODE_MEDIA ) == self.MODE_MEDIA:
+        if (self.mode & self.MODE_MEDIA) == self.MODE_MEDIA:
             nl1 = source_ref1.get_media_list()
             nl2 = source_ref2.get_media_list()
             if len(nl1) != len(nl2):
