@@ -16,13 +16,14 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # gen/proxy/__init__.py
 
-__all__ = [ "filter", "living", "private", "proxybase", "referenced" ]
+__all__ = ["filter", "living", "private", "proxybase", "referencedbyselection"]
 
 from .filter import FilterProxyDb
 from .living import LivingProxyDb
 from .private import PrivateProxyDb
 from .referencedbyselection import ReferencedBySelectionProxyDb
+from .cache import CacheProxyDb
