@@ -10,41 +10,62 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
 Proxy class for the Gramps databases. Filter out all data marked private.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python libraries
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ..const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 import logging
+
 LOG = logging.getLogger(".citation")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS libraries
+# Gramps libraries
 #
-#-------------------------------------------------------------------------
-from ..lib import (MediaRef, Attribute, Address, EventRef, 
-                   Person, Name, Source, RepoRef, MediaObject, Place, Event, 
-                   Family, ChildRef, Repository, LdsOrd, Surname, Citation,
-                   SrcAttribute, Note, Tag)
+# -------------------------------------------------------------------------
+from ..lib import (
+    MediaRef,
+    Attribute,
+    Address,
+    EventRef,
+    Person,
+    Name,
+    Source,
+    RepoRef,
+    Media,
+    Place,
+    Event,
+    Family,
+    ChildRef,
+    Repository,
+    LdsOrd,
+    Surname,
+    Citation,
+    SrcAttribute,
+    Note,
+    Tag,
+)
 from .proxybase import ProxyDbBase
 
+
 class PrivateProxyDb(ProxyDbBase):
     """
     A proxy to a Gramps database. This proxy will act like a Gramps database,
@@ -53,89 +74,9 @@ class PrivateProxyDb(ProxyDbBase):
 
     def __init__(self, db):
         """
-        Create a new PrivateProxyDb instance. 
+        Create a new PrivateProxyDb instance.
         """
         ProxyDbBase.__init__(self, db)
-        self._tables['Person'].update(
-            {
-                "handle_func": self.get_person_from_handle, 
-                "gramps_id_func": self.get_person_from_gramps_id,
-                "class_func": Person,
-                "cursor_func": self.get_person_cursor,
-                "handles_func": self.get_person_handles,
-            })
-        self._tables['Family'].update(
-            {
-                "handle_func": self.get_family_from_handle, 
-                "gramps_id_func": self.get_family_from_gramps_id,
-                "class_func": Family,
-                "cursor_func": self.get_family_cursor,
-                "handles_func": self.get_family_handles,
-            })
-        self._tables['Source'].update(
-            {
-                "handle_func": self.get_source_from_handle, 
-                "gramps_id_func": self.get_source_from_gramps_id,
-                "class_func": Source,
-                "cursor_func": self.get_source_cursor,
-                "handles_func": self.get_source_handles,
-                })
-        self._tables['Citation'].update(
-            {
-                "handle_func": self.get_citation_from_handle, 
-                "gramps_id_func": self.get_citation_from_gramps_id,
-                "class_func": Citation,
-                "cursor_func": self.get_citation_cursor,
-                "handles_func": self.get_citation_handles,
-            })
-        self._tables['Event'].update(
-            {
-                "handle_func": self.get_event_from_handle, 
-                "gramps_id_func": self.get_event_from_gramps_id,
-                "class_func": Event,
-                "cursor_func": self.get_event_cursor,
-                "handles_func": self.get_event_handles,
-            })
-        self._tables['Media'].update(
-            {
-                "handle_func": self.get_object_from_handle, 
-                "gramps_id_func": self.get_object_from_gramps_id,
-                "class_func": MediaObject,
-                "cursor_func": self.get_media_cursor,
-                "handles_func": self.get_media_object_handles,
-            })
-        self._tables['Place'].update(
-            {
-                "handle_func": self.get_place_from_handle, 
-                "gramps_id_func": self.get_place_from_gramps_id,
-                "class_func": Place,
-                "cursor_func": self.get_place_cursor,
-                "handles_func": self.get_place_handles,
-            })
-        self._tables['Repository'].update(
-            {
-                "handle_func": self.get_repository_from_handle, 
-                "gramps_id_func": self.get_repository_from_gramps_id,
-                "class_func": Repository,
-                "cursor_func": self.get_repository_cursor,
-                "handles_func": self.get_repository_handles,
-            })
-        self._tables['Note'].update(
-            {
-                "handle_func": self.get_note_from_handle, 
-                "gramps_id_func": self.get_note_from_gramps_id,
-                "class_func": Note,
-                "cursor_func": self.get_note_cursor,
-                "handles_func": self.get_note_handles,
-            })
-        self._tables['Tag'].update(
-            {
-                "handle_func": self.get_tag_from_handle, 
-                "gramps_id_func": None,
-                "class_func": Tag,
-                "cursor_func": self.get_tag_cursor,
-                "handles_func": self.get_tag_handles,
-            })
 
     def get_person_from_handle(self, handle):
         """
@@ -167,12 +108,12 @@ class PrivateProxyDb(ProxyDbBase):
             return sanitize_citation(self.db, citation)
         return None
 
-    def get_object_from_handle(self, handle):
+    def get_media_from_handle(self, handle):
         """
         Finds an Object in the database from the passed Gramps ID.
         If no such Object exists, None is returned.
         """
-        media = self.db.get_object_from_handle(handle)
+        media = self.db.get_media_from_handle(handle)
         if media and not media.get_privacy():
             return sanitize_media(self.db, media)
         return None
@@ -229,7 +170,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_person_from_gramps_id(self, val):
         """
-        Finds a Person in the database from the passed GRAMPS ID.
+        Finds a Person in the database from the passed Gramps ID.
         If no such Person exists, None is returned.
         """
         person = self.db.get_person_from_gramps_id(val)
@@ -239,7 +180,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_family_from_gramps_id(self, val):
         """
-        Finds a Family in the database from the passed GRAMPS ID.
+        Finds a Family in the database from the passed Gramps ID.
         If no such Family exists, None is returned.
         """
         family = self.db.get_family_from_gramps_id(val)
@@ -249,7 +190,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_event_from_gramps_id(self, val):
         """
-        Finds an Event in the database from the passed GRAMPS ID.
+        Finds an Event in the database from the passed Gramps ID.
         If no such Event exists, None is returned.
         """
         event = self.db.get_event_from_gramps_id(val)
@@ -287,12 +228,12 @@ class PrivateProxyDb(ProxyDbBase):
             return sanitize_citation(self.db, citation)
         return None
 
-    def get_object_from_gramps_id(self, val):
+    def get_media_from_gramps_id(self, val):
         """
-        Finds a MediaObject in the database from the passed Gramps ID.
-        If no such MediaObject exists, None is returned.
+        Finds a Media in the database from the passed Gramps ID.
+        If no such Media exists, None is returned.
         """
-        obj = self.db.get_object_from_gramps_id(val)
+        obj = self.db.get_media_from_gramps_id(val)
         if obj and not obj.get_privacy():
             return sanitize_media(self.db, obj)
         return None
@@ -318,67 +259,67 @@ class PrivateProxyDb(ProxyDbBase):
         return None
 
     # Define predicate functions for use by default iterator methods
-    
+
     def include_person(self, handle):
         """
         Predicate returning True if object is to be included, else False
         """
         obj = self.get_unfiltered_person(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_family(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_family(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_event(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_event(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_source(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_source(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_citation(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_citation(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_place(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_place(handle)
         return obj and not obj.get_privacy()
-    
-    def include_media_object(self, handle):
+
+    def include_media(self, handle):
         """
         Predicate returning True if object is to be included, else False
         """
-        obj = self.get_unfiltered_object(handle)
+        obj = self.get_unfiltered_media(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_repository(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_repository(handle)
         return obj and not obj.get_privacy()
-    
+
     def include_note(self, handle):
         """
         Predicate returning True if object is to be included, else False
-        """        
+        """
         obj = self.get_unfiltered_note(handle)
         return obj and not obj.get_privacy()
 
@@ -392,11 +333,12 @@ class PrivateProxyDb(ProxyDbBase):
     def get_default_handle(self):
         """returns the default Person of the database"""
         handle = self.db.get_default_handle()
-        person = self.db.get_person_from_handle(handle)
-        if person and not person.get_privacy():
-            return handle
+        if handle:
+            person = self.db.get_person_from_handle(handle)
+            if person and not person.get_privacy():
+                return handle
         return None
-    
+
     def has_person_handle(self, handle):
         """
         returns True if the handle exists in the current Person database.
@@ -442,7 +384,7 @@ class PrivateProxyDb(ProxyDbBase):
             return True
         return False
 
-    def has_family_handle(self, handle):            
+    def has_family_handle(self, handle):
         """
         Return True if the handle exists in the current Family database.
         """
@@ -453,9 +395,9 @@ class PrivateProxyDb(ProxyDbBase):
 
     def has_object_handle(self, handle):
         """
-        Return True if the handle exists in the current MediaObjectdatabase.
+        Return True if the handle exists in the current Mediadatabase.
         """
-        object = self.db.get_object_from_handle(handle)
+        object = self.db.get_media_from_handle(handle)
         if object and not object.get_privacy():
             return True
         return False
@@ -488,7 +430,7 @@ class PrivateProxyDb(ProxyDbBase):
         :param include_classes: list of class names to include in the results.
                                 Default: None means include all classes.
         :type include_classes: list of class names
-        
+
         This default implementation does a sequential scan through all
         the primary object databases and is very slow. Backends can
         override this method to provide much faster implementations that
@@ -499,36 +441,37 @@ class PrivateProxyDb(ProxyDbBase):
 
         >    result_list = list(find_backlink_handles(handle))
         """
-        
+
         # This isn't done yet because it doesn't check if references are
-        # private (like a MediaRef). It only checks if the 
+        # private (like a MediaRef). It only checks if the
         # referenced object is private.
 
         objects = {
-            'Person'        : self.db.get_person_from_handle,
-            'Family'        : self.db.get_family_from_handle,
-            'Event'         : self.db.get_event_from_handle,
-            'Source'        : self.db.get_source_from_handle,
-            'Citation'      : self.db.get_citation_from_handle,
-            'Place'         : self.db.get_place_from_handle,
-            'MediaObject'   : self.db.get_object_from_handle,
-            'Note'          : self.db.get_note_from_handle,
-            'Repository'    : self.db.get_repository_from_handle,
-            }
+            "Person": self.db.get_person_from_handle,
+            "Family": self.db.get_family_from_handle,
+            "Event": self.db.get_event_from_handle,
+            "Source": self.db.get_source_from_handle,
+            "Citation": self.db.get_citation_from_handle,
+            "Place": self.db.get_place_from_handle,
+            "Media": self.db.get_media_from_handle,
+            "Note": self.db.get_note_from_handle,
+            "Repository": self.db.get_repository_from_handle,
+        }
 
         handle_itr = self.db.find_backlink_handles(handle, include_classes)
-        for (class_name, handle) in handle_itr:
+        for class_name, handle in handle_itr:
             if class_name in objects:
                 obj = objects[class_name](handle)
                 if obj and not obj.get_privacy():
                     yield (class_name, handle)
             else:
-                raise NotImplementedError                
+                raise NotImplementedError
         return
 
+
 def copy_media_ref_list(db, original_obj, clean_obj):
     """
-    Copies media references from one object to another - excluding private 
+    Copies media references from one object to another - excluding private
     references and references to private objects.
 
     :param db: Gramps database to which the references belongs
@@ -542,10 +485,11 @@ def copy_media_ref_list(db, original_obj, clean_obj):
     for media_ref in original_obj.get_media_list():
         if media_ref and not media_ref.get_privacy():
             handle = media_ref.get_reference_handle()
-            media_object = db.get_object_from_handle(handle)
-            if media_object and not media_object.get_privacy():
+            media = db.get_media_from_handle(handle)
+            if media and not media.get_privacy():
                 clean_obj.add_media_reference(sanitize_media_ref(db, media_ref))
 
+
 def copy_citation_ref_list(db, original_obj, clean_obj):
     """
     Copies citation references from one object to another - excluding references
@@ -567,7 +511,8 @@ def copy_citation_ref_list(db, original_obj, clean_obj):
             source = db.get_source_from_handle(handle)
             if source and not source.get_privacy():
                 clean_obj.add_citation(citation_handle)
-                
+
+
 def copy_notes(db, original_obj, clean_obj):
     """
     Copies notes from one object to another - excluding references to private
@@ -580,12 +525,13 @@ def copy_notes(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private references
     :type original_obj: NoteBase
     :returns: Nothing
-    """     
+    """
     for note_handle in original_obj.get_note_list():
         note = db.get_note_from_handle(note_handle)
         if note and not note.get_privacy():
             clean_obj.add_note(note_handle)
 
+
 def copy_associations(db, original_obj, clean_obj):
     """
     Copies associations from one object to another - excluding
@@ -607,9 +553,10 @@ def copy_associations(db, original_obj, clean_obj):
                 new_person_ref_list.append(person_ref)
     clean_obj.set_person_ref_list(new_person_ref_list)
 
+
 def copy_attributes(db, original_obj, clean_obj):
     """
-    Copies attributes from one object to another - excluding references to 
+    Copies attributes from one object to another - excluding references to
     private attributes.
 
     :param db: Gramps database to which the references belongs
@@ -619,7 +566,7 @@ def copy_attributes(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private references
     :type original_obj: AttributeBase
     :returns: Nothing
-    """   
+    """
     for attribute in original_obj.get_attribute_list():
         if attribute and not attribute.get_privacy():
             new_attribute = Attribute()
@@ -629,9 +576,10 @@ def copy_attributes(db, original_obj, clean_obj):
             copy_citation_ref_list(db, attribute, new_attribute)
             clean_obj.add_attribute(new_attribute)
 
+
 def copy_srcattributes(db, original_obj, clean_obj):
     """
-    Copies srcattributes from one object to another - excluding references to 
+    Copies srcattributes from one object to another - excluding references to
     private srcattributes.
 
     :param db: Gramps database to which the references belongs
@@ -641,7 +589,7 @@ def copy_srcattributes(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private references
     :type original_obj: SrcAttributeBase
     :returns: Nothing
-    """   
+    """
     for attribute in original_obj.get_attribute_list():
         if attribute and not attribute.get_privacy():
             new_attribute = SrcAttribute()
@@ -649,9 +597,10 @@ def copy_srcattributes(db, original_obj, clean_obj):
             new_attribute.set_value(attribute.get_value())
             clean_obj.add_attribute(new_attribute)
 
+
 def copy_urls(db, original_obj, clean_obj):
     """
-    Copies urls from one object to another - excluding references to 
+    Copies urls from one object to another - excluding references to
     private urls.
 
     :param db: Gramps database to which the references belongs
@@ -661,14 +610,15 @@ def copy_urls(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private urls
     :type original_obj: UrlBase
     :returns: Nothing
-    """         
+    """
     for url in original_obj.get_url_list():
         if url and not url.get_privacy():
             clean_obj.add_url(url)
-            
+
+
 def copy_lds_ords(db, original_obj, clean_obj):
     """
-    Copies LDS ORDs from one object to another - excluding references to 
+    Copies LDS ORDs from one object to another - excluding references to
     private LDS ORDs.
 
     :param db: Gramps database to which the references belongs
@@ -678,14 +628,15 @@ def copy_lds_ords(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private LDS ORDs
     :type original_obj: LdsOrdBase
     :returns: Nothing
-    """         
+    """
     for lds_ord in original_obj.get_lds_ord_list():
         if lds_ord and not lds_ord.get_privacy():
             clean_obj.add_lds_ord(sanitize_lds_ord(db, lds_ord))
-           
+
+
 def copy_addresses(db, original_obj, clean_obj):
     """
-    Copies addresses from one object to another - excluding references to 
+    Copies addresses from one object to another - excluding references to
     private addresses.
 
     :param db: Gramps database to which the references belongs
@@ -695,17 +646,18 @@ def copy_addresses(db, original_obj, clean_obj):
     :param clean_obj: Object that will have only non-private addresses
     :type original_obj: AddressBase
     :returns: Nothing
-    """         
+    """
     for address in original_obj.get_address_list():
         if address and not address.get_privacy():
             clean_obj.add_address(sanitize_address(db, address))
 
+
 def sanitize_lds_ord(db, lds_ord):
     """
     Create a new LdsOrd instance based off the passed LdsOrd
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the LdsOrd object belongs
     :type db: DbBase
     :param name: source LdsOrd object that will be copied with
@@ -720,28 +672,31 @@ def sanitize_lds_ord(db, lds_ord):
     new_lds_ord.set_temple(lds_ord.get_temple())
 
     fam_handle = lds_ord.get_family_handle()
-    fam = db.get_family_from_handle(fam_handle)
-    if fam and not fam.get_privacy():
-        new_lds_ord.set_family_handle(fam_handle)
-    
+    if fam_handle:
+        fam = db.get_family_from_handle(fam_handle)
+        if fam and not fam.get_privacy():
+            new_lds_ord.set_family_handle(fam_handle)
+
     new_lds_ord.set_date_object(lds_ord.get_date_object())
-    
+
     place_handle = lds_ord.get_place_handle()
-    place = db.get_place_from_handle(place_handle)
-    if place and not place.get_privacy():
-        new_lds_ord.set_place_handle(place_handle)
+    if place_handle:
+        place = db.get_place_from_handle(place_handle)
+        if place and not place.get_privacy():
+            new_lds_ord.set_place_handle(place_handle)
 
     copy_citation_ref_list(db, lds_ord, new_lds_ord)
     copy_notes(db, lds_ord, new_lds_ord)
-    
+
     return new_lds_ord
-    
+
+
 def sanitize_address(db, address):
     """
     Create a new Address instance based off the passed Address
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param name: source Address object that will be copied with
@@ -751,7 +706,7 @@ def sanitize_address(db, address):
     :rtype: Address
     """
     new_address = Address()
-    
+
     new_address.set_street(address.get_street())
     new_address.set_locality(address.get_locality())
     new_address.set_city(address.get_city())
@@ -760,19 +715,20 @@ def sanitize_address(db, address):
     new_address.set_country(address.get_country())
     new_address.set_postal_code(address.get_postal_code())
     new_address.set_phone(address.get_phone())
-    
+
     new_address.set_date_object(address.get_date_object())
     copy_citation_ref_list(db, address, new_address)
     copy_notes(db, address, new_address)
-    
+
     return new_address
-    
+
+
 def sanitize_name(db, name):
     """
     Create a new Name instance based off the passed Name
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param name: source Name object that will be copied with
@@ -794,18 +750,19 @@ def sanitize_name(db, name):
     new_name.set_title(name.get_title())
     new_name.set_date_object(name.get_date_object())
     new_name.set_surname_list(name.get_surname_list())
-    
+
     copy_citation_ref_list(db, name, new_name)
     copy_notes(db, name, new_name)
-    
+
     return new_name
 
+
 def sanitize_media_ref(db, media_ref):
     """
     Create a new MediaRef instance based off the passed MediaRef
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the MediaRef object belongs
     :type db: DbBase
     :param source_ref: source MediaRef object that will be copied with
@@ -816,20 +773,21 @@ def sanitize_media_ref(db, media_ref):
     """
     new_ref = MediaRef()
     new_ref.set_rectangle(media_ref.get_rectangle())
-    
+
     new_ref.set_reference_handle(media_ref.get_reference_handle())
     copy_notes(db, media_ref, new_ref)
     copy_attributes(db, media_ref, new_ref)
     copy_citation_ref_list(db, media_ref, new_ref)
-    
+
     return new_ref
 
+
 def sanitize_citation(db, citation):
     """
     Create a new Citation instance based off the passed Citation
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param citation: source Citation object that will be copied with
@@ -846,18 +804,20 @@ def sanitize_citation(db, citation):
     new_citation.set_gramps_id(citation.get_gramps_id())
     new_citation.set_handle(citation.get_handle())
     new_citation.set_change_time(citation.get_change_time())
+    new_citation.set_tag_list(citation.get_tag_list())
     copy_srcattributes(db, citation, new_citation)
     copy_notes(db, citation, new_citation)
     copy_media_ref_list(db, citation, new_citation)
-    
+
     return new_citation
-    
+
+
 def sanitize_event_ref(db, event_ref):
     """
     Create a new EventRef instance based off the passed EventRef
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param event_ref: source EventRef object that will be copied with
@@ -867,20 +827,22 @@ def sanitize_event_ref(db, event_ref):
     :rtype: EventRef
     """
     new_ref = EventRef()
-    
+
     new_ref.set_reference_handle(event_ref.get_reference_handle())
     new_ref.set_role(event_ref.get_role())
+    copy_citation_ref_list(db, event_ref, new_ref)
     copy_notes(db, event_ref, new_ref)
     copy_attributes(db, event_ref, new_ref)
-    
+
     return new_ref
 
+
 def sanitize_person(db, person):
     """
     Create a new Person instance based off the passed Person
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param person: source Person object that will be copied with
@@ -897,14 +859,14 @@ def sanitize_person(db, person):
     new_person.set_handle(person.get_handle())
     new_person.set_change_time(person.get_change_time())
     new_person.set_tag_list(person.get_tag_list())
-    
+
     # copy names if not private
     name = person.get_primary_name()
     if (name and name.get_privacy()) or (person and person.get_privacy()):
         # Do this so a person always has a primary name of some sort.
         name = Name()
         surn = Surname()
-        surn.set_surname(_('Private'))
+        surn.set_surname(_("Private"))
         name.set_surname_list([surn])
         name.set_primary_surname()
     else:
@@ -965,15 +927,16 @@ def sanitize_person(db, person):
     copy_lds_ords(db, person, new_person)
     copy_notes(db, person, new_person)
     copy_associations(db, person, new_person)
-    
+
     return new_person
 
+
 def sanitize_source(db, source):
     """
     Create a new Source instance based off the passed Source
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param source: source Source object that will be copied with
@@ -983,7 +946,7 @@ def sanitize_source(db, source):
     :rtype: Source
     """
     new_source = Source()
-    
+
     new_source.set_author(source.get_author())
     new_source.set_title(source.get_title())
     new_source.set_publication_info(source.get_publication_info())
@@ -991,7 +954,8 @@ def sanitize_source(db, source):
     new_source.set_gramps_id(source.get_gramps_id())
     new_source.set_handle(source.get_handle())
     new_source.set_change_time(source.get_change_time())
-    
+    new_source.set_tag_list(source.get_tag_list())
+
     for repo_ref in source.get_reporef_list():
         if repo_ref and not repo_ref.get_privacy():
             handle = repo_ref.get_reference_handle()
@@ -1002,25 +966,26 @@ def sanitize_source(db, source):
     copy_srcattributes(db, source, new_source)
     copy_media_ref_list(db, source, new_source)
     copy_notes(db, source, new_source)
-    
+
     return new_source
 
+
 def sanitize_media(db, media):
     """
-    Create a new MediaObject instance based off the passed Media
+    Create a new Media instance based off the passed Media
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param media: source Media object that will be copied with
                   privacy records removed
-    :type media: MediaObject
+    :type media: Media
     :returns: 'cleansed' Media object
-    :rtype: MediaObject
+    :rtype: Media
     """
-    new_media = MediaObject()
-    
+    new_media = Media()
+
     new_media.set_mime_type(media.get_mime_type())
     new_media.set_path(media.get_path())
     new_media.set_description(media.get_description())
@@ -1029,6 +994,7 @@ def sanitize_media(db, media):
     new_media.set_change_time(media.get_change_time())
     new_media.set_date_object(media.get_date_object())
     new_media.set_tag_list(media.get_tag_list())
+    new_media.set_checksum(media.get_checksum())
 
     copy_citation_ref_list(db, media, new_media)
     copy_attributes(db, media, new_media)
@@ -1036,12 +1002,13 @@ def sanitize_media(db, media):
 
     return new_media
 
+
 def sanitize_place(db, place):
     """
     Create a new Place instance based off the passed Place
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param place: source Place object that will be copied with
@@ -1051,7 +1018,7 @@ def sanitize_place(db, place):
     :rtype: Place
     """
     new_place = Place()
-    
+
     new_place.set_title(place.get_title())
     new_place.set_gramps_id(place.get_gramps_id())
     new_place.set_handle(place.get_handle())
@@ -1060,23 +1027,26 @@ def sanitize_place(db, place):
     new_place.set_latitude(place.get_latitude())
     new_place.set_alternate_locations(place.get_alternate_locations())
     new_place.set_name(place.get_name())
+    new_place.set_alternative_names(place.get_alternative_names())
     new_place.set_type(place.get_type())
     new_place.set_code(place.get_code())
     new_place.set_placeref_list(place.get_placeref_list())
+    new_place.set_tag_list(place.get_tag_list())
 
     copy_citation_ref_list(db, place, new_place)
     copy_notes(db, place, new_place)
     copy_media_ref_list(db, place, new_place)
     copy_urls(db, place, new_place)
-    
+
     return new_place
 
+
 def sanitize_event(db, event):
     """
     Create a new Event instance based off the passed Event
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param event: source Event object that will be copied with
@@ -1086,32 +1056,35 @@ def sanitize_event(db, event):
     :rtype: Event
     """
     new_event = Event()
-    
+
     new_event.set_type(event.get_type())
     new_event.set_description(event.get_description())
     new_event.set_gramps_id(event.get_gramps_id())
     new_event.set_handle(event.get_handle())
     new_event.set_date_object(event.get_date_object())
     new_event.set_change_time(event.get_change_time())
+    new_event.set_tag_list(event.get_tag_list())
 
     copy_citation_ref_list(db, event, new_event)
     copy_notes(db, event, new_event)
     copy_media_ref_list(db, event, new_event)
     copy_attributes(db, event, new_event)
-    
+
     place_handle = event.get_place_handle()
-    place = db.get_place_from_handle(place_handle)
-    if place and not place.get_privacy():
-        new_event.set_place_handle(place_handle)
-    
+    if place_handle:
+        place = db.get_place_from_handle(place_handle)
+        if place and not place.get_privacy():
+            new_event.set_place_handle(place_handle)
+
     return new_event
-            
+
+
 def sanitize_family(db, family):
     """
     Create a new Family instance based off the passed Family
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param family: source Family object that will be copied with
@@ -1121,13 +1094,13 @@ def sanitize_family(db, family):
     :rtype: Family
     """
     new_family = Family()
-    
+
     new_family.set_gramps_id(family.get_gramps_id())
     new_family.set_handle(family.get_handle())
     new_family.set_relationship(family.get_relationship())
     new_family.set_change_time(family.get_change_time())
     new_family.set_tag_list(family.get_tag_list())
-    
+
     # Copy the father handle.
     father_handle = family.get_father_handle()
     if father_handle:
@@ -1141,7 +1114,7 @@ def sanitize_family(db, family):
         mother = db.get_person_from_handle(mother_handle)
         if mother and not mother.get_privacy():
             new_family.set_mother_handle(mother_handle)
-        
+
     # Copy child references.
     for child_ref in family.get_child_ref_list():
         if child_ref and child_ref.get_privacy():
@@ -1158,7 +1131,7 @@ def sanitize_family(db, family):
         copy_notes(db, child_ref, new_ref)
         copy_citation_ref_list(db, child_ref, new_ref)
         new_family.add_child_ref(new_ref)
-        
+
     # Copy event ref list.
     for event_ref in family.get_event_ref_list():
         if event_ref and not event_ref.get_privacy():
@@ -1171,15 +1144,16 @@ def sanitize_family(db, family):
     copy_media_ref_list(db, family, new_family)
     copy_attributes(db, family, new_family)
     copy_lds_ords(db, family, new_family)
-    
+
     return new_family
 
+
 def sanitize_repository(db, repository):
     """
     Create a new Repository instance based off the passed Repository
     instance. The returned instance has all private records
     removed from it.
-    
+
     :param db: Gramps database to which the Person object belongs
     :type db: DbBase
     :param repository: source Repository object that will be copied with
@@ -1189,15 +1163,16 @@ def sanitize_repository(db, repository):
     :rtype: Repository
     """
     new_repository = Repository()
-    
+
     new_repository.set_type(repository.get_type())
     new_repository.set_name(repository.get_name())
     new_repository.set_gramps_id(repository.get_gramps_id())
     new_repository.set_handle(repository.get_handle())
     new_repository.set_change_time(repository.get_change_time())
+    new_repository.set_tag_list(repository.get_tag_list())
 
     copy_notes(db, repository, new_repository)
     copy_addresses(db, repository, new_repository)
     copy_urls(db, repository, new_repository)
-    
+
     return new_repository
