@@ -17,49 +17,59 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
 Provide a simplified database access interface to the Gramps database.
 """
-from __future__ import with_statement, unicode_literals
-
-from ..lib import (Person, Family, Event, Source, Place, Citation, 
-                   MediaObject, Repository, Note, Date, Tag)
-from ..lib.handle import Handle
+from ..lib import (
+    Person,
+    Family,
+    Event,
+    Source,
+    Place,
+    Citation,
+    Media,
+    Repository,
+    Note,
+    Date,
+    Tag,
+)
+from ..errors import HandleError
 from ..datehandler import displayer
 from ..utils.string import gender as gender_map
 from ..utils.db import get_birth_or_fallback, get_death_or_fallback
-from ..plug.report.utils import place_name
 
 from ..display.name import displayer as name_displayer
+from ..display.place import displayer as place_displayer
 from ..lib import EventType
 from ..config import config
 from ..const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
-from ..constfunc import STRTYPE
 
-#-------------------------------------------------------------------------
+_ = glocale.translation.gettext
+
+
+# -------------------------------------------------------------------------
 #
 # Local functions
 #
-#-------------------------------------------------------------------------
-class SimpleAccess(object):
+# -------------------------------------------------------------------------
+class SimpleAccess:
     """
     Provide a simplified database access system. This system has been designed
     to ease the development of reports.
-    
-    The user needs to take care when using this interface. Since it returns real 
+
+    The user needs to take care when using this interface. Since it returns real
     objects instead of database references, it can consume a significant amount
     of memory if the user is not careful.
-    
+
     **Example**
-    
+
     A typical system of usage would be::
-    
+
       sa = SimpleAccess(database)
-    
+
       print "Person        : ", sa.name(person)
       print "Gender        : ", sa.gender(person)
       print "Birth date    : ", sa.birth_date(person)
@@ -74,10 +84,10 @@ class SimpleAccess(object):
       print "Marriage Place: ", sa.marriage_place(person)
       for child in sa.children(person):
          print "Child         : ", sa.name(child)
-        
+
       # Print out burial and baptism events
       for event in sa.events( person , [ "Burial", "Baptism" ]):
-         print "Event         : ", sa.event_type(event), sa.event_date(event), 
+         print "Event         : ", sa.event_type(event), sa.event_date(event),
          print sa.event_place(event)
 
     This would produce an output that looks like::
@@ -110,7 +120,7 @@ class SimpleAccess(object):
     def __init__(self, dbase):
         """
         Initialize the SimpleAccess object with the database that will be used.
-        
+
         :param dbase: Gramps database object
         :type dbase: DbBase
         """
@@ -125,13 +135,13 @@ class SimpleAccess(object):
         :return: Returns the name of the person based of the program preferences
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE):
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))     
+        assert person is None or isinstance(person, Person)
         if person:
             return name_displayer.display(person)
         else:
-            return ''
+            return ""
 
     def surname(self, person):
         """
@@ -142,15 +152,15 @@ class SimpleAccess(object):
         :return: Returns the name of the person based of the program preferences
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))     
+        assert person is None or isinstance(person, Person)
         if person:
             surname = person.get_primary_name().get_surname()
-            return surname or config.get('preferences.no-surname-text')
+            return surname or config.get("preferences.no-surname-text")
         else:
-            return ''
-        
+            return ""
+
     def first_name(self, person):
         """
         Return the first name of the person, or and empty string if the person
@@ -162,13 +172,13 @@ class SimpleAccess(object):
                  preferences
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
         if person:
             return person.get_primary_name().get_first_name()
         else:
-            return ''
+            return ""
 
     def gid(self, obj):
         """
@@ -182,7 +192,7 @@ class SimpleAccess(object):
         if obj:
             return obj.get_gramps_id()
         else:
-            return ''
+            return ""
 
     def gender(self, person):
         """
@@ -193,12 +203,12 @@ class SimpleAccess(object):
         :return: Returns a string indentifying the person's gender
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
         if person:
             return gender_map[person.get_gender()]
-        return ''
+        return ""
 
     def __parent(self, person, func):
         """
@@ -211,7 +221,7 @@ class SimpleAccess(object):
         :return: mother or father of the associated person
         :rtype: :py:class:`.Person`
         """
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             parent_handle_list = person.get_parent_family_handle_list()
@@ -232,7 +242,7 @@ class SimpleAccess(object):
         :return: mother or father of the associated family
         :rtype: :py:class:`.Family`
         """
-        assert(family is None or isinstance(family, Family))
+        assert family is None or isinstance(family, Family)
 
         if family:
             handle = func(family)
@@ -251,7 +261,7 @@ class SimpleAccess(object):
         :return: Returns a string describing the date
         :rtype: unicode
         """
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             ref = func(person)
@@ -262,7 +272,7 @@ class SimpleAccess(object):
                     date_obj = event.get_date_object()
                     if date_obj:
                         return displayer.display(date_obj)
-        return ''
+        return ""
 
     def __event_date_obj(self, person, func):
         """
@@ -275,7 +285,7 @@ class SimpleAccess(object):
         :return: Returns the date
         :rtype: l{gen.lib.Date}
         """
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             ref = func(person)
@@ -301,7 +311,7 @@ class SimpleAccess(object):
         :return: Returns a string describing the place
         :rtype: unicode
         """
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             ref = func(person)
@@ -309,9 +319,8 @@ class SimpleAccess(object):
                 event_handle = ref.get_reference_handle()
                 if event_handle:
                     event = self.dbase.get_event_from_handle(event_handle)
-                    place_handle = event.get_place_handle()
-                    return place_name(self.dbase, place_handle)
-        return ''
+                    return place_displayer.display_event(self.dbase, event)
+        return ""
 
     def spouse(self, person):
         """
@@ -322,9 +331,9 @@ class SimpleAccess(object):
         :return: The spouse identified as the person's primary spouse
         :rtype: :py:class:`.Person`
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             family_handle_list = person.get_family_handle_list()
@@ -350,9 +359,9 @@ class SimpleAccess(object):
                  person and his/per primary spouse.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             family_handle_list = person.get_family_handle_list()
@@ -361,7 +370,7 @@ class SimpleAccess(object):
                 family = self.dbase.get_family_from_handle(family_id)
                 if family:
                     return str(family.get_relationship())
-        return ''
+        return ""
 
     def marriage_place(self, person):
         """
@@ -374,9 +383,9 @@ class SimpleAccess(object):
                  his/her spouse where married.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             family_handle_list = person.get_family_handle_list()
@@ -386,14 +395,16 @@ class SimpleAccess(object):
                 if family:
                     reflist = family.get_event_ref_list()
                     if reflist:
-                        elist = [ self.dbase.get_event_from_handle(ref.ref) 
-                                  for ref in reflist ]
-                        events = [ evnt for evnt in elist 
-                                   if event.type == EventType.MARRIAGE ]
+                        # 'evnt' should be renamed to 'event'?
+                        elist = [
+                            self.dbase.get_event_from_handle(ref.ref) for ref in reflist
+                        ]
+                        events = [
+                            evnt for evnt in elist if evnt.type == EventType.MARRIAGE
+                        ]
                         if events:
-                            place_handle = events[0].get_place_handle()
-                            return place_name(self.dbase, place_handle)
-        return ''
+                            return place_displayer.display_event(self.dbase, events[0])
+        return ""
 
     def marriage_date(self, person):
         """
@@ -406,9 +417,9 @@ class SimpleAccess(object):
                  his/her spouse where married.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
+        assert person is None or isinstance(person, Person)
 
         if person:
             family_handle_list = person.get_family_handle_list()
@@ -418,15 +429,17 @@ class SimpleAccess(object):
                 if family:
                     reflist = family.get_event_ref_list()
                     if reflist:
-                        elist = [ self.dbase.get_event_from_handle(ref.ref) 
-                                  for ref in reflist ]
-                        events = [ evnt for evnt in elist 
-                                   if event.type == EventType.MARRIAGE ]
+                        elist = [
+                            self.dbase.get_event_from_handle(ref.ref) for ref in reflist
+                        ]
+                        events = [
+                            evnt for evnt in elist if evnt.type == EventType.MARRIAGE
+                        ]
                         if events:
                             date_obj = events[0].get_date_object()
                             if date_obj:
                                 return displayer.display(date_obj)
-        return ''
+        return ""
 
     def children(self, obj):
         """
@@ -438,19 +451,23 @@ class SimpleAccess(object):
                  children
         :rtype: list
         """
-        assert(obj is None or isinstance(obj, (Person, Family)))
+        assert obj is None or isinstance(obj, (Person, Family))
 
         if isinstance(obj, Person):
             family_handle_list = obj.get_family_handle_list()
             if family_handle_list:
                 family_id = family_handle_list[0]
                 family = self.dbase.get_family_from_handle(family_id)
-                
-                return [ self.dbase.get_person_from_handle(hndl.ref) 
-                         for hndl in family.get_child_ref_list() ]
+
+                return [
+                    self.dbase.get_person_from_handle(hndl.ref)
+                    for hndl in family.get_child_ref_list()
+                ]
         elif isinstance(obj, Family):
-            return [ self.dbase.get_person_from_handle(hndl.ref) 
-                     for hndl in obj.get_child_ref_list() ]
+            return [
+                self.dbase.get_person_from_handle(hndl.ref)
+                for hndl in obj.get_child_ref_list()
+            ]
         return []
 
     def father(self, obj):
@@ -488,7 +505,7 @@ class SimpleAccess(object):
             return self.__family_parent(obj, Family.get_mother_handle)
         else:
             return None
-        
+
     def birth_date(self, person):
         """
         Return a string indicating the date when the person's birth.
@@ -498,7 +515,7 @@ class SimpleAccess(object):
         :return: Returns a string indicating the date when the person's birth.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_date(person, Person.get_birth_ref)
 
@@ -511,11 +528,10 @@ class SimpleAccess(object):
         :return: Returns the date when the person's birth.
         :rtype: :py:class:`.Date`
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_date_obj(person, Person.get_birth_ref)
 
-
     def birth_or_fallback(self, person, get_event=False):
         """
         Return the date of the person's birth or fallback event.
@@ -525,7 +541,7 @@ class SimpleAccess(object):
         :return: Returns the date when the person's birth or fallback.
         :rtype: :py:class:`.Date`
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         event = get_birth_or_fallback(self.dbase, person, "<i>%s</i>")
         if get_event:
@@ -544,7 +560,7 @@ class SimpleAccess(object):
         :return: Returns a string indicating the place of the person's birth.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_place(person, Person.get_birth_ref)
 
@@ -557,7 +573,7 @@ class SimpleAccess(object):
         :return: Returns a string indicating the date when the person's death.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE):
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_date(person, Person.get_death_ref)
 
@@ -570,7 +586,7 @@ class SimpleAccess(object):
         :return: Returns the date when the person's death.
         :rtype: :py:class:`.Date`
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_date_obj(person, Person.get_death_ref)
 
@@ -583,7 +599,7 @@ class SimpleAccess(object):
         :return: Returns the date of the person's death or fallback.
         :rtype: :py:class:`.Date`
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         event = get_death_or_fallback(self.dbase, person, "<i>%s</i>")
         if get_event:
@@ -602,7 +618,7 @@ class SimpleAccess(object):
         :return: Returns a string indicating the place of the person's death.
         :rtype: unicode
         """
-        if isinstance(person, STRTYPE): 
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
         return self.__event_place(person, Person.get_death_ref)
 
@@ -615,13 +631,12 @@ class SimpleAccess(object):
         :return: Returns a string indicating the place of the event
         :rtype: unicode
         """
-        assert(event is None or isinstance(event, Event))
+        assert event is None or isinstance(event, Event)
 
         if event:
-            place_handle = event.get_place_handle()
-            return place_name(self.dbase, place_handle)
+            return place_displayer.display_event(self.dbase, event)
         else:
-            return ''
+            return ""
 
     def date_string(self, date_obj):
         """
@@ -635,7 +650,7 @@ class SimpleAccess(object):
         if date_obj:
             return displayer.display(date_obj)
         else:
-            return ''
+            return ""
 
     def event_date(self, event):
         """
@@ -646,12 +661,12 @@ class SimpleAccess(object):
         :return: Returns a string indicating the date of the event
         :rtype: unicode
         """
-        assert(event is None or isinstance(event, Event))
+        assert event is None or isinstance(event, Event)
         date_obj = event.get_date_object()
         if date_obj:
             return displayer.display(date_obj)
         else:
-            return ''
+            return ""
 
     def event_date_obj(self, event):
         """
@@ -662,7 +677,7 @@ class SimpleAccess(object):
         :return: Returns a string indicating the date of the event
         :rtype: unicode
         """
-        assert(event is None or isinstance(event, Event))
+        assert event is None or isinstance(event, Event)
         if event:
             return event.get_date_object()
 
@@ -675,11 +690,11 @@ class SimpleAccess(object):
         :return: Returns a string indicating the type of the event
         :rtype: unicode
         """
-        assert(event is None or isinstance(event, Event))
+        assert event is None or isinstance(event, Event)
         if event:
             return str(event.get_type())
         else:
-            return ''
+            return ""
 
     def events(self, obj, restrict=None):
         """
@@ -694,17 +709,19 @@ class SimpleAccess(object):
         :return: list of events associated with the object
         :rtype: list
         """
-        assert(obj is None or isinstance(obj, (Person, Family)))
-        assert(isinstance(restrict, list) or restrict is None)
+        assert obj is None or isinstance(obj, (Person, Family))
+        assert isinstance(restrict, list) or restrict is None
 
         if obj:
-            event_handles = [ ref.ref for ref in obj.get_event_ref_list() ]
-            events = [ self.dbase.get_event_from_handle(h) 
-                       for h in event_handles ]
+            event_handles = [ref.ref for ref in obj.get_event_ref_list()]
+            events = [self.dbase.get_event_from_handle(h) for h in event_handles]
             if restrict:
-                restrict = [ r.lower() for r in restrict ]
-                events = [ event for event in events 
-                           if str(event.get_type()).lower() in restrict ]
+                restrict = [r.lower() for r in restrict]
+                events = [
+                    event
+                    for event in events
+                    if str(event.get_type()).lower() in restrict
+                ]
             return events
         else:
             return []
@@ -719,10 +736,10 @@ class SimpleAccess(object):
         :return: list of events associated with the object
         :rtype: list
         """
-        assert(obj is None or isinstance(obj, (Person, Family, Event)))
+        assert obj is None or isinstance(obj, (Person, Family, Event))
 
         if obj:
-            handles = [ ref.ref for ref in obj.get_source_references() ]
+            handles = [ref.ref for ref in obj.get_source_references()]
             return list(map(self.dbase.get_source_from_handle, handles))
         else:
             return []
@@ -737,13 +754,15 @@ class SimpleAccess(object):
                  listed as a parent.
         :rtype: list
         """
-        if isinstance(person, STRTYPE):
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))     
-        
+        assert person is None or isinstance(person, Person)
+
         if person:
-            return [ self.dbase.get_family_from_handle(handle) 
-                     for handle in person.get_family_handle_list() ]
+            return [
+                self.dbase.get_family_from_handle(handle)
+                for handle in person.get_family_handle_list()
+            ]
         return []
 
     def child_in(self, person):
@@ -756,24 +775,26 @@ class SimpleAccess(object):
                  listed as a child.
         :rtype: list
         """
-        if isinstance(person, STRTYPE):
+        if isinstance(person, str):
             person = self.dbase.get_person_from_handle(person)
-        assert(person is None or isinstance(person, Person))
-        
+        assert person is None or isinstance(person, Person)
+
         if person:
-            return [ self.dbase.get_family_from_handle(handle) 
-                     for handle in person.get_parent_family_handle_list() ]
+            return [
+                self.dbase.get_family_from_handle(handle)
+                for handle in person.get_parent_family_handle_list()
+            ]
         return []
 
     def __all_objects(self, gen_cursor, get_object):
         """
-        Return a all the objects of a particular type in the database, one 
-        at a time as an iterator. The user can treat this just like a list. 
+        Return a all the objects of a particular type in the database, one
+        at a time as an iterator. The user can treat this just like a list.
 
         :return: list of objects of a particular type in the database
         :rtype: list
         """
-        
+
         with gen_cursor() as cursor:
             for key, data in cursor:
                 yield get_object(key)
@@ -789,9 +810,12 @@ class SimpleAccess(object):
         :return: list of people in the database
         :rtype: list
         """
-        
+
         with self.dbase.get_person_cursor() as cursor:
-            slist = sorted((data[3][3], key) for key, data in cursor)
+            # data[3] is primary_name; data[3][5][0][0] is surname
+            slist = sorted(
+                (data[3][5][0][0] if data[3][5] else "", key) for key, data in cursor
+            )
 
         for info in slist:
             obj = self.dbase.get_person_from_handle(info[1])
@@ -808,8 +832,9 @@ class SimpleAccess(object):
         :return: list of families in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_family_cursor, 
-                                  self.dbase.get_family_from_handle)
+        return self.__all_objects(
+            self.dbase.get_family_cursor, self.dbase.get_family_from_handle
+        )
 
     def all_events(self):
         """
@@ -822,8 +847,9 @@ class SimpleAccess(object):
         :return: list of events in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_event_cursor, 
-                                  self.dbase.get_event_from_handle)
+        return self.__all_objects(
+            self.dbase.get_event_cursor, self.dbase.get_event_from_handle
+        )
 
     def all_sources(self):
         """
@@ -833,8 +859,9 @@ class SimpleAccess(object):
         :return: list of sources in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_source_cursor, 
-                                  self.dbase.get_source_from_handle)
+        return self.__all_objects(
+            self.dbase.get_source_cursor, self.dbase.get_source_from_handle
+        )
 
     def all_citations(self):
         """
@@ -844,8 +871,9 @@ class SimpleAccess(object):
         :return: list of citations in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_citation_cursor, 
-                                  self.dbase.get_citation_from_handle)
+        return self.__all_objects(
+            self.dbase.get_citation_cursor, self.dbase.get_citation_from_handle
+        )
 
     def all_repositories(self):
         """
@@ -855,8 +883,9 @@ class SimpleAccess(object):
         :return: list of repositories in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_repsoitory_cursor, 
-                                  self.dbase.get_repository_from_handle)
+        return self.__all_objects(
+            self.dbase.get_repository_cursor, self.dbase.get_repository_from_handle
+        )
 
     def all_media(self):
         """
@@ -866,8 +895,9 @@ class SimpleAccess(object):
         :return: list of media in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_media_cursor, 
-                                  self.dbase.get_object_from_handle)
+        return self.__all_objects(
+            self.dbase.get_media_cursor, self.dbase.get_media_from_handle
+        )
 
     def all_places(self):
         """
@@ -877,8 +907,9 @@ class SimpleAccess(object):
         :return: list of places in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_place_cursor, 
-                                  self.dbase.get_place_from_handle)
+        return self.__all_objects(
+            self.dbase.get_place_cursor, self.dbase.get_place_from_handle
+        )
 
     def all_notes(self):
         """
@@ -888,8 +919,9 @@ class SimpleAccess(object):
         :return: list of notes in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_note_cursor, 
-                                  self.dbase.get_note_from_handle)
+        return self.__all_objects(
+            self.dbase.get_note_cursor, self.dbase.get_note_from_handle
+        )
 
     def all_tags(self):
         """
@@ -899,8 +931,9 @@ class SimpleAccess(object):
         :return: list of tags in the database
         :rtype: list
         """
-        return self.__all_objects(self.dbase.get_tag_cursor, 
-                                  self.dbase.get_tag_from_handle)
+        return self.__all_objects(
+            self.dbase.get_tag_cursor, self.dbase.get_tag_from_handle
+        )
 
     def title(self, source):
         """
@@ -911,10 +944,10 @@ class SimpleAccess(object):
         :return: title of the source
         :rtype: unicode
         """
-        assert(source is None or isinstance(source, Source))
+        assert source is None or isinstance(source, Source)
         if source:
             return source.get_title()
-        return ''
+        return ""
 
     def page(self, citation):
         """
@@ -925,10 +958,10 @@ class SimpleAccess(object):
         :return: title of the citation
         :rtype: unicode
         """
-        assert(citation is None or isinstance(citation, Citation))
+        assert citation is None or isinstance(citation, Citation)
         if citation:
             return citation.get_page()
-        return ''
+        return ""
 
     def author(self, source):
         """
@@ -939,124 +972,118 @@ class SimpleAccess(object):
         :return: author of the source
         :rtype: unicode
         """
-        assert(source is None or isinstance(source, Source))
+        assert source is None or isinstance(source, Source)
         if source:
             return source.get_author()
-        return ''
+        return ""
 
     def person(self, handle):
-        assert(isinstance(handle, STRTYPE))
+        assert isinstance(handle, str)
         return self.dbase.get_person_from_handle(handle)
 
     def event(self, handle):
-        assert(isinstance(handle, STRTYPE))
+        assert isinstance(handle, str)
         return self.dbase.get_event_from_handle(handle)
 
     def family(self, handle):
-        assert(isinstance(handle, STRTYPE))
+        assert isinstance(handle, str)
         return self.dbase.get_family_from_handle(handle)
 
     def display(self, object_class, prop, value):
         """
         Given a object_class, prop, and value return a display string
-        describing object.  
+        describing object.
 
         :param object_class: "Person", "Source", etc.
         :param prop: "gramps_id", or "handle"
         :param value: gramps_id or handle.
         """
-        if object_class in self.dbase.get_table_names():
-            obj = self.dbase.get_table_metadata(object_class)\
-                           [prop + "_func"](value)
+        func = self.dbase.method("get_%s_from_%s", object_class, prop)
+        if func:
+            try:
+                obj = func(value)
+            except HandleError:
+                # Deals with deleted objects referenced in Note Links
+                obj = None
             if obj:
                 if isinstance(obj, Person):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            self.name(obj), 
-                                            self.gid(obj))
+                    return "%s: %s [%s]" % (
+                        _(object_class),
+                        self.name(obj),
+                        self.gid(obj),
+                    )
                 elif isinstance(obj, Event):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            self.event_type(obj),
-                                            self.gid(obj))
+                    return "%s: %s [%s]" % (
+                        _(object_class),
+                        self.event_type(obj),
+                        self.gid(obj),
+                    )
                 elif isinstance(obj, Family):
-                    return "%s: %s/%s [%s]" % (_(object_class), 
-                                            self.name(self.mother(obj)), 
-                                            self.name(self.father(obj)), 
-                                            self.gid(obj))
-                elif isinstance(obj, MediaObject):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            obj.desc, 
-                                            self.gid(obj))
+                    return "%s: %s/%s [%s]" % (
+                        _(object_class),
+                        self.name(self.mother(obj)),
+                        self.name(self.father(obj)),
+                        self.gid(obj),
+                    )
+                elif isinstance(obj, Media):
+                    return "%s: %s [%s]" % (_(object_class), obj.desc, self.gid(obj))
                 elif isinstance(obj, Source):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            self.title(obj), 
-                                            self.gid(obj))
+                    return "%s: %s [%s]" % (
+                        _(object_class),
+                        self.title(obj),
+                        self.gid(obj),
+                    )
                 elif isinstance(obj, Citation):
-                    return "%s: [%s]" % (_(object_class), 
-                                            self.gid(obj))
+                    return "%s: [%s]" % (_(object_class), self.gid(obj))
                 elif isinstance(obj, Place):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            place_name(self.dbase, 
-                                                       obj.handle), 
-                                            self.gid(obj))
+                    place_title = place_displayer.display(self.dbase, obj)
+                    return "%s: %s [%s]" % (_(object_class), place_title, self.gid(obj))
                 elif isinstance(obj, Repository):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            obj.type, 
-                                            self.gid(obj))
+                    return "%s: %s [%s]" % (_(object_class), obj.type, self.gid(obj))
                 elif isinstance(obj, Note):
-                    return "%s: %s [%s]" % (_(object_class), 
-                                            obj.type, 
-                                            self.gid(obj))
+                    return "%s: %s [%s]" % (_(object_class), obj.type, self.gid(obj))
                 elif isinstance(obj, Tag):
-                    return "%s: [%s]" % (_(object_class), 
-                                         obj.name)
+                    return "%s: [%s]" % (_(object_class), obj.name)
                 else:
                     return "Error: incorrect object class in display: '%s'" % type(obj)
             else:
                 return "Error: missing object"
-        elif object_class == "Handle":
-            return "%s.handle [%s]" % (prop, value)
         else:
             return "Error: invalid object class in display: '%s'" % object_class
 
     def describe(self, obj, prop=None, value=None):
         """
-        Given a object, return a string describing the object.  
+        Given a object, return a string describing the object.
         """
         if prop and value:
-            if self.dbase.get_table_metadata(obj):
-                obj = self.dbase.get_table_metadata(obj)[prop + "_func"](value)
+            func = self.dbase.method("get_%s_from_%s", object_class, prop)
+            if func:
+                obj = func(value)
         if isinstance(obj, Person):
-            return "%s [%s]" % (self.name(obj), 
-                                self.gid(obj))
+            return "%s [%s]" % (self.name(obj), self.gid(obj))
         elif isinstance(obj, Event):
-            return "%s [%s]" % (self.event_type(obj),
-                                self.gid(obj))
+            return "%s [%s]" % (self.event_type(obj), self.gid(obj))
         elif isinstance(obj, Family):
-            return "%s/%s [%s]" % (self.name(self.mother(obj)), 
-                                   self.name(self.father(obj)), 
-                                   self.gid(obj))
-        elif isinstance(obj, MediaObject):
-            return "%s [%s]" % (obj.desc, 
-                                self.gid(obj))
+            return "%s/%s [%s]" % (
+                self.name(self.mother(obj)),
+                self.name(self.father(obj)),
+                self.gid(obj),
+            )
+        elif isinstance(obj, Media):
+            return "%s [%s]" % (obj.desc, self.gid(obj))
         elif isinstance(obj, Source):
-            return "%s [%s]" % (self.title(obj), 
-                                self.gid(obj))
+            return "%s [%s]" % (self.title(obj), self.gid(obj))
         elif isinstance(obj, Citation):
             return "[%s]" % (self.gid(obj))
         elif isinstance(obj, Place):
-            return "%s [%s]" % (place_name(self.dbase, 
-                                           obj.handle), 
-                                self.gid(obj))
+            place_title = place_displayer.display(self.dbase, obj)
+            return "%s [%s]" % (place_title, self.gid(obj))
         elif isinstance(obj, Repository):
-            return "%s [%s]" % (obj.type, 
-                                self.gid(obj))
+            return "%s [%s]" % (obj.type, self.gid(obj))
         elif isinstance(obj, Note):
-            return "%s [%s]" % (obj.type, 
-                                self.gid(obj))
+            return "%s [%s]" % (obj.type, self.gid(obj))
         elif isinstance(obj, Tag):
             return "[%s]" % (obj.name)
-        elif isinstance(obj, Handle):
-            return "%s.handle [%s]" % (prop, obj.handle)
         else:
             return "Error: incorrect object class in describe: '%s'" % type(obj)
 
@@ -1068,27 +1095,6 @@ class SimpleAccess(object):
         :param prop: "gramps_id", or "handle"
         :param value: gramps_id or handle.
         """
-        if object_class in self.dbase.get_table_names():
-            return self.dbase.get_table_metadata(object_class) \
-                [prop + "_func"](value)
-
-def by_date(event1, event2):
-    """
-    Sort function that will compare two events by their dates.
-
-    :param event1: first event
-    :type event1: :py:class:`.Event`
-    :param event2: second event
-    :type event2: :py:class:`.Event`
-    :return: Returns -1 if event1 < event2, 0 if they are equal, and
-       1 if they are the same.
-    :rtype: int
-    """
-    if event1 and event2:
-        return cmp(event1.get_date_object() , event2.get_date_object())
-    elif event1:
-        return -1
-    elif event2:
-        return 1
-    else:
-        return 0
+        func = self.dbase.method("get_%s_from_%s", object_class, prop)
+        if func:
+            return func(value)
