@@ -18,27 +18,28 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from html import escape
 import logging
+
 log = logging.getLogger(".")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GNOME/GTK modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.datehandler import format_time, get_date, get_date_valid
 from gramps.gen.lib import Event, EventType
 from gramps.gen.utils.db import get_participant_from_event
@@ -47,11 +48,11 @@ from gramps.gen.config import config
 from .flatbasemodel import FlatBaseModel
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Positions in raw data structure
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 COLUMN_HANDLE = 0
 COLUMN_ID = 1
 COLUMN_TYPE = 2
@@ -62,17 +63,25 @@ COLUMN_CHANGE = 10
 COLUMN_TAGS = 11
 COLUMN_PRIV = 12
 
-INVALID_DATE_FORMAT = config.get('preferences.invalid-date-format')
+INVALID_DATE_FORMAT = config.get("preferences.invalid-date-format")
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # EventModel
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class EventModel(FlatBaseModel):
-
-    def __init__(self, db, uistate, scol=0, order=Gtk.SortType.ASCENDING,
-                 search=None, skip=set(), sort_map=None):
+    def __init__(
+        self,
+        db,
+        uistate,
+        scol=0,
+        order=Gtk.SortType.ASCENDING,
+        search=None,
+        skip=set(),
+        sort_map=None,
+    ):
         self.gen_cursor = db.get_event_cursor
         self.map = db.get_raw_event_data
 
@@ -86,8 +95,8 @@ class EventModel(FlatBaseModel):
             self.column_tags,
             self.column_change,
             self.column_participant,
-            self.column_tag_color
-            ]
+            self.column_tag_color,
+        ]
         self.smap = [
             self.column_description,
             self.column_id,
@@ -98,10 +107,11 @@ class EventModel(FlatBaseModel):
             self.column_tags,
             self.sort_change,
             self.column_participant,
-            self.column_tag_color
-           ]
-        FlatBaseModel.__init__(self, db, uistate, scol, order, search=search,
-                               skip=skip, sort_map=sort_map)
+            self.column_tag_color,
+        ]
+        FlatBaseModel.__init__(
+            self, db, uistate, scol, order, search=search, skip=skip, sort_map=sort_map
+        )
 
     def destroy(self):
         """
@@ -121,21 +131,22 @@ class EventModel(FlatBaseModel):
         return 9
 
     def on_get_n_columns(self):
-        return len(self.fmap)+1
+        return len(self.fmap) + 1
 
-    def column_description(self,data):
+    def column_description(self, data):
         return data[COLUMN_DESCRIPTION]
 
-    def column_participant(self,data):
+    def column_participant(self, data):
         handle = data[0]
         cached, value = self.get_cached_value(handle, "PARTICIPANT")
         if not cached:
-            value = get_participant_from_event(self.db, data[COLUMN_HANDLE],
-                                               all_=True) # all participants
+            value = get_participant_from_event(
+                self.db, data[COLUMN_HANDLE], all_=True
+            )  # all participants
             self.set_cached_value(handle, "PARTICIPANT", value)
         return value
 
-    def column_place(self,data):
+    def column_place(self, data):
         if data[COLUMN_PLACE]:
             cached, value = self.get_cached_value(data[0], "PLACE")
             if not cached:
@@ -145,28 +156,30 @@ class EventModel(FlatBaseModel):
                 self.set_cached_value(data[0], "PLACE", value)
             return value
         else:
-            return ''
+            return ""
 
-    def column_type(self,data):
+    def column_type(self, data):
         return str(EventType(data[COLUMN_TYPE]))
 
-    def column_id(self,data):
+    def column_id(self, data):
         return data[COLUMN_ID]
 
-    def column_date(self,data):
+    def column_date(self, data):
         if data[COLUMN_DATE]:
             event = Event()
             event.unserialize(data)
             date_str = get_date(event)
             if date_str != "":
                 retval = escape(date_str)
+            else:
+                retval = ""
             if not get_date_valid(event):
                 return INVALID_DATE_FORMAT % retval
             else:
                 return retval
-        return ''
+        return ""
 
-    def sort_date(self,data):
+    def sort_date(self, data):
         if data[COLUMN_DATE]:
             event = Event()
             event.unserialize(data)
@@ -176,19 +189,19 @@ class EventModel(FlatBaseModel):
             else:
                 return retval
 
-        return ''
+        return ""
 
     def column_private(self, data):
         if data[COLUMN_PRIV]:
-            return 'gramps-lock'
+            return "gramps-lock"
         else:
             # There is a problem returning None here.
-            return ''
+            return ""
 
-    def sort_change(self,data):
+    def sort_change(self, data):
         return "%012x" % data[COLUMN_CHANGE]
 
-    def column_change(self,data):
+    def column_change(self, data):
         return format_time(data[COLUMN_CHANGE])
 
     def get_tag_name(self, tag_handle):
@@ -226,4 +239,4 @@ class EventModel(FlatBaseModel):
         """
         tag_list = list(map(self.get_tag_name, data[COLUMN_TAGS]))
         # TODO for Arabic, should the next line's comma be translated?
-        return ', '.join(sorted(tag_list, key=glocale.sort_key))
+        return ", ".join(sorted(tag_list, key=glocale.sort_key))
