@@ -19,41 +19,51 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import logging
+
 _LOG = logging.getLogger(".gui.notemodel")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GNOME/GTK modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.datehandler import format_time
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 from .flatbasemodel import FlatBaseModel
-from gramps.gen.lib import (Note, NoteType, StyledText)
+from gramps.gen.lib import Note, NoteType, StyledText
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # NoteModel
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class NoteModel(FlatBaseModel):
-    """
-    """
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+    """ """
+
+    def __init__(
+        self,
+        db,
+        uistate,
+        scol=0,
+        order=Gtk.SortType.ASCENDING,
+        search=None,
+        skip=set(),
+        sort_map=None,
+    ):
         """Setup initial values for instance variables."""
         self.gen_cursor = db.get_note_cursor
         self.map = db.get_raw_note_data
@@ -64,7 +74,7 @@ class NoteModel(FlatBaseModel):
             self.column_private,
             self.column_tags,
             self.column_change,
-            self.column_tag_color
+            self.column_tag_color,
         ]
         self.smap = [
             self.column_preview,
@@ -73,10 +83,11 @@ class NoteModel(FlatBaseModel):
             self.column_private,
             self.column_tags,
             self.sort_change,
-            self.column_tag_color
+            self.column_tag_color,
         ]
-        FlatBaseModel.__init__(self, db, scol, order, search=search, skip=skip,
-                               sort_map=sort_map)
+        FlatBaseModel.__init__(
+            self, db, uistate, scol, order, search=search, skip=skip, sort_map=sort_map
+        )
 
     def destroy(self):
         """
@@ -101,7 +112,7 @@ class NoteModel(FlatBaseModel):
 
     def column_id(self, data):
         """Return the id of the Note."""
-        return str(data[Note.POS_ID])
+        return data[Note.POS_ID]
 
     def column_type(self, data):
         """Return the type of the Note in readable format."""
@@ -111,9 +122,7 @@ class NoteModel(FlatBaseModel):
 
     def column_preview(self, data):
         """Return a shortend version of the Note's text."""
-        #data is the encoding in the database, make it a unicode object
-        #for universal work
-        note = str(data[Note.POS_TEXT][StyledText.POS_TEXT])
+        note = data[Note.POS_TEXT][StyledText.POS_TEXT]
         note = " ".join(note.split())
         if len(note) > 80:
             return note[:80] + "..."
@@ -122,15 +131,15 @@ class NoteModel(FlatBaseModel):
 
     def column_private(self, data):
         if data[Note.POS_PRIVATE]:
-            return 'gramps-lock'
+            return "gramps-lock"
         else:
             # There is a problem returning None here.
-            return ''
+            return ""
 
     def sort_change(self, data):
         return "%012x" % data[Note.POS_CHANGE]
-    
-    def column_change(self,data):
+
+    def column_change(self, data):
         return format_time(data[Note.POS_CHANGE])
 
     def get_tag_name(self, tag_handle):
@@ -140,9 +149,9 @@ class NoteModel(FlatBaseModel):
         cached, value = self.get_cached_value(tag_handle, "TAG_NAME")
         if not cached:
             value = self.db.get_tag_from_handle(tag_handle).get_name()
-            self.set_cached_value(tag_handle, "TAG_NAME", value)        
-        return value 
-        
+            self.set_cached_value(tag_handle, "TAG_NAME", value)
+        return value
+
     def column_tag_color(self, data):
         """
         Return the tag color.
@@ -160,12 +169,13 @@ class NoteModel(FlatBaseModel):
                         tag_color = tag.get_color()
                         tag_priority = this_priority
             value = tag_color
-            self.set_cached_value(tag_handle, "TAG_COLOR", value)        
-        return value 
+            self.set_cached_value(tag_handle, "TAG_COLOR", value)
+        return value
 
     def column_tags(self, data):
         """
         Return the sorted list of tags.
         """
         tag_list = list(map(self.get_tag_name, data[Note.POS_TAGS]))
-        return ', '.join(sorted(tag_list, key=glocale.sort_key))
+        # TODO for Arabic, should the next line's comma be translated?
+        return ", ".join(sorted(tag_list, key=glocale.sort_key))
