@@ -22,41 +22,50 @@
 #
 
 """
-TreeModel for the GRAMPS Person tree.
+TreeModel for the Gramps Person tree.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from html import escape
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GTK modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
 from gi.repository import GObject
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # set up logging
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import logging
+
 _LOG = logging.getLogger(".")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
-from gramps.gen.lib import (Name, EventRef, EventType, EventRoleType,
-                            FamilyRelType, ChildRefType, NoteType)
+from gramps.gen.lib import (
+    Name,
+    EventRef,
+    EventType,
+    EventRoleType,
+    FamilyRelType,
+    ChildRefType,
+    NoteType,
+)
 from gramps.gen.display.name import displayer as name_displayer
 from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.datehandler import format_time, get_date, get_date_valid
@@ -64,38 +73,40 @@ from .flatbasemodel import FlatBaseModel
 from .treebasemodel import TreeBaseModel
 from .basemodel import BaseModel
 from gramps.gen.config import config
-from gramps.gen.const import GRAMPS_LOCALE as glocale
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # COLUMN constants; positions in raw data structure
 #
-#-------------------------------------------------------------------------
-COLUMN_ID     = 1
+# -------------------------------------------------------------------------
+COLUMN_ID = 1
 COLUMN_GENDER = 2
-COLUMN_NAME   = 3
-COLUMN_DEATH  = 5
-COLUMN_BIRTH  = 6
-COLUMN_EVENT  = 7
+COLUMN_NAME = 3
+COLUMN_DEATH = 5
+COLUMN_BIRTH = 6
+COLUMN_EVENT = 7
 COLUMN_FAMILY = 8
 COLUMN_PARENT = 9
-COLUMN_NOTES  = 16
+COLUMN_NOTES = 16
 COLUMN_CHANGE = 17
-COLUMN_TAGS   = 18
-COLUMN_PRIV   = 19
+COLUMN_TAGS = 18
+COLUMN_PRIV = 19
 
-invalid_date_format = config.get('preferences.invalid-date-format')
+invalid_date_format = config.get("preferences.invalid-date-format")
+no_surname = config.get("preferences.no-surname-text")
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # PeopleBaseModel
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PeopleBaseModel(BaseModel):
     """
     Basic Model interface to handle the PersonViews
     """
-    _GENDER = [ _('female'), _('male'), _('unknown') ]
+
+    _GENDER = [_("female"), _("male"), _("unknown"), _("other")]
 
     def __init__(self, db):
         """
@@ -123,7 +134,7 @@ class PeopleBaseModel(BaseModel):
             self.column_tags,
             self.column_change,
             self.column_tag_color,
-            ]
+        ]
         self.smap = [
             self.sort_name,
             self.column_id,
@@ -141,7 +152,7 @@ class PeopleBaseModel(BaseModel):
             self.column_tags,
             self.sort_change,
             self.column_tag_color,
-            ]
+        ]
 
     def destroy(self):
         """
@@ -161,17 +172,14 @@ class PeopleBaseModel(BaseModel):
         return 15
 
     def on_get_n_columns(self):
-        """ Return the number of columns in the model """
-        return len(self.fmap)+1
+        """Return the number of columns in the model"""
+        return len(self.fmap) + 1
 
     def sort_name(self, data):
         handle = data[0]
         cached, name = self.get_cached_value(handle, "SORT_NAME")
         if not cached:
             name = name_displayer.raw_sorted_name(data[COLUMN_NAME])
-            # internally we work with utf-8
-            if not isinstance(name, str):
-                name = name.decode('utf-8')
             self.set_cached_value(handle, "SORT_NAME", name)
         return name
 
@@ -180,9 +188,6 @@ class PeopleBaseModel(BaseModel):
         cached, name = self.get_cached_value(handle, "NAME")
         if not cached:
             name = name_displayer.raw_display_name(data[COLUMN_NAME])
-            # internally we work with utf-8 for python 2.7
-            if not isinstance(name, str):
-                name = name.encode('utf-8')
             self.set_cached_value(handle, "NAME", name)
         return name
 
@@ -196,17 +201,16 @@ class PeopleBaseModel(BaseModel):
 
     def column_private(self, data):
         if data[COLUMN_PRIV]:
-            return 'gramps-lock'
+            return "gramps-lock"
         else:
             # There is a problem returning None here.
-            return ''
-    
+            return ""
+
     def _get_spouse_data(self, data):
         spouses_names = ""
         for family_handle in data[COLUMN_FAMILY]:
             family = self.db.get_family_from_handle(family_handle)
-            for spouse_id in [family.get_father_handle(),
-                              family.get_mother_handle()]:
+            for spouse_id in [family.get_father_handle(), family.get_mother_handle()]:
                 if not spouse_id:
                     continue
                 if spouse_id == data[0]:
@@ -220,7 +224,7 @@ class PeopleBaseModel(BaseModel):
     def column_id(self, data):
         return data[COLUMN_ID]
 
-    def sort_change(self,data):
+    def sort_change(self, data):
         return "%012x" % data[COLUMN_CHANGE]
 
     def column_change(self, data):
@@ -236,7 +240,7 @@ class PeopleBaseModel(BaseModel):
             value = self._get_birth_data(data, False)
             self.set_cached_value(handle, "BIRTH_DAY", value)
         return value
-        
+
     def sort_birth_day(self, data):
         handle = data[0]
         cached, value = self.get_cached_value(handle, "SORT_BIRTH_DAY")
@@ -264,17 +268,19 @@ class PeopleBaseModel(BaseModel):
                 else:
                     return retval
             except:
-                return ''
-        
+                return ""
+
         for event_ref in data[COLUMN_EVENT]:
             er = EventRef()
             er.unserialize(event_ref)
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
             date_str = get_date(event)
-            if (etype in [EventType.BAPTISM, EventType.CHRISTEN]
+            if (
+                etype.is_birth_fallback()
                 and er.get_role() == EventRoleType.PRIMARY
-                and date_str != ""):
+                and date_str != ""
+            ):
                 if sort_mode:
                     retval = "%09d" % event.get_date_object().get_sort_value()
                 else:
@@ -283,7 +289,7 @@ class PeopleBaseModel(BaseModel):
                     return invalid_date_format % retval
                 else:
                     return retval
-        
+
         return ""
 
     def column_death_day(self, data):
@@ -293,7 +299,7 @@ class PeopleBaseModel(BaseModel):
             value = self._get_death_data(data, False)
             self.set_cached_value(handle, "DEATH_DAY", value)
         return value
-        
+
     def sort_death_day(self, data):
         handle = data[0]
         cached, value = self.get_cached_value(handle, "SORT_DEATH_DAY")
@@ -321,19 +327,19 @@ class PeopleBaseModel(BaseModel):
                 else:
                     return retval
             except:
-                return ''
-        
+                return ""
+
         for event_ref in data[COLUMN_EVENT]:
             er = EventRef()
             er.unserialize(event_ref)
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
             date_str = get_date(event)
-            if (etype in [EventType.BURIAL,
-                          EventType.CREMATION,
-                          EventType.CAUSE_DEATH]
+            if (
+                etype.is_death_fallback()
                 and er.get_role() == EventRoleType.PRIMARY
-                and date_str):
+                and date_str
+            ):
                 if sort_mode:
                     retval = "%09d" % event.get_date_object().get_sort_value()
                 else:
@@ -364,22 +370,21 @@ class PeopleBaseModel(BaseModel):
                             self.set_cached_value(handle, "BIRTH_PLACE", value)
                             return value
                 except:
-                    value = ''
+                    value = ""
                     self.set_cached_value(handle, "BIRTH_PLACE", value)
                     return value
-        
+
             for event_ref in data[COLUMN_EVENT]:
                 er = EventRef()
                 er.unserialize(event_ref)
                 event = self.db.get_event_from_handle(er.ref)
                 etype = event.get_type()
-                if (etype in [EventType.BAPTISM, EventType.CHRISTEN] and
-                    er.get_role() == EventRoleType.PRIMARY):
-                        place_title = place_displayer.display_event(self.db, event)
-                        if place_title:
-                            value = "<i>%s</i>" % escape(place_title)
-                            self.set_cached_value(handle, "BIRTH_PLACE", value)
-                            return value
+                if etype.is_birth_fallback() and er.get_role() == EventRoleType.PRIMARY:
+                    place_title = place_displayer.display_event(self.db, event)
+                    if place_title:
+                        value = "<i>%s</i>" % escape(place_title)
+                        self.set_cached_value(handle, "BIRTH_PLACE", value)
+                        return value
             value = ""
             self.set_cached_value(handle, "BIRTH_PLACE", value)
             return value
@@ -404,7 +409,7 @@ class PeopleBaseModel(BaseModel):
                             self.set_cached_value(handle, "DEATH_PLACE", value)
                             return value
                 except:
-                    value = ''
+                    value = ""
                     self.set_cached_value(handle, "DEATH_PLACE", value)
                     return value
 
@@ -413,15 +418,12 @@ class PeopleBaseModel(BaseModel):
                 er.unserialize(event_ref)
                 event = self.db.get_event_from_handle(er.ref)
                 etype = event.get_type()
-                if (etype in [EventType.BURIAL, EventType.CREMATION,
-                              EventType.CAUSE_DEATH]
-                    and er.get_role() == EventRoleType.PRIMARY):
-
-                        place_title = place_displayer.display_event(self.db, event)
-                        if place_title:
-                            value = "<i>%s</i>" % escape(place_title)
-                            self.set_cached_value(handle, "DEATH_PLACE", value)
-                            return value
+                if etype.is_death_fallback() and er.get_role() == EventRoleType.PRIMARY:
+                    place_title = place_displayer.display_event(self.db, event)
+                    if place_title:
+                        value = "<i>%s</i>" % escape(place_title)
+                        self.set_cached_value(handle, "DEATH_PLACE", value)
+                        return value
             value = ""
             self.set_cached_value(handle, "DEATH_PLACE", value)
             return value
@@ -429,11 +431,14 @@ class PeopleBaseModel(BaseModel):
     def _get_parents_data(self, data):
         parents = 0
         if data[COLUMN_PARENT]:
-            family = self.db.get_family_from_handle(data[COLUMN_PARENT][0])
-            if family.get_father_handle():
-                parents += 1
-            if family.get_mother_handle():
-                parents += 1
+            person = self.db.get_person_from_gramps_id(data[COLUMN_ID])
+            family_list = person.get_parent_family_handle_list()
+            for fam_hdle in family_list:
+                family = self.db.get_family_from_handle(fam_hdle)
+                if family.get_father_handle():
+                    parents += 1
+                if family.get_mother_handle():
+                    parents += 1
         return parents
 
     def _get_marriages_data(self, data):
@@ -449,8 +454,10 @@ class PeopleBaseModel(BaseModel):
         for family_handle in data[COLUMN_FAMILY]:
             family = self.db.get_family_from_handle(family_handle)
             for child_ref in family.get_child_ref_list():
-                if (child_ref.get_father_relation() == ChildRefType.BIRTH and 
-                    child_ref.get_mother_relation() == ChildRefType.BIRTH):
+                if (
+                    child_ref.get_father_relation() == ChildRefType.BIRTH
+                    and child_ref.get_mother_relation() == ChildRefType.BIRTH
+                ):
                     children += 1
         return children
 
@@ -476,7 +483,7 @@ class PeopleBaseModel(BaseModel):
         if not cached:
             value = self._get_parents_data(data)
             self.set_cached_value(handle, "SORT_PARENTS", value)
-        return '%06d' % value
+        return "%06d" % value
 
     def column_marriages(self, data):
         handle = data[0]
@@ -492,7 +499,7 @@ class PeopleBaseModel(BaseModel):
         if not cached:
             value = self._get_marriages_data(data)
             self.set_cached_value(handle, "SORT_MARRIAGES", value)
-        return '%06d' % value
+        return "%06d" % value
 
     def column_children(self, data):
         handle = data[0]
@@ -508,7 +515,7 @@ class PeopleBaseModel(BaseModel):
         if not cached:
             value = self._get_children_data(data)
             self.set_cached_value(handle, "SORT_CHILDREN", value)
-        return '%06d' % value
+        return "%06d" % value
 
     def column_todo(self, data):
         handle = data[0]
@@ -524,7 +531,7 @@ class PeopleBaseModel(BaseModel):
         if not cached:
             value = self._get_todo_data(data)
             self.set_cached_value(handle, "SORT_TODO", value)
-        return '%06d' % value
+        return "%06d" % value
 
     def get_tag_name(self, tag_handle):
         """
@@ -536,7 +543,7 @@ class PeopleBaseModel(BaseModel):
             if tag:
                 value = tag.get_name()
                 self.set_cached_value(tag_handle, "TAG_NAME", value)
-        return value 
+        return value
 
     def column_tag_color(self, data):
         """
@@ -555,8 +562,8 @@ class PeopleBaseModel(BaseModel):
                         tag_color = tag.get_color()
                         tag_priority = this_priority
             value = tag_color
-            self.set_cached_value(tag_handle, "TAG_COLOR", value)        
-        return value 
+            self.set_cached_value(tag_handle, "TAG_COLOR", value)
+        return value
 
     def column_tags(self, data):
         """
@@ -566,19 +573,38 @@ class PeopleBaseModel(BaseModel):
         cached, value = self.get_cached_value(handle, "TAGS")
         if not cached:
             tag_list = list(map(self.get_tag_name, data[COLUMN_TAGS]))
-            value = ', '.join(sorted(tag_list, key=glocale.sort_key))
+            # TODO for Arabic, should the next line's comma be translated?
+            value = ", ".join(sorted(tag_list, key=glocale.sort_key))
             self.set_cached_value(handle, "TAGS", value)
         return value
 
+
 class PersonListModel(PeopleBaseModel, FlatBaseModel):
     """
     Listed people model.
     """
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+
+    def __init__(
+        self,
+        db,
+        uistate,
+        scol=0,
+        order=Gtk.SortType.ASCENDING,
+        search=None,
+        skip=set(),
+        sort_map=None,
+    ):
         PeopleBaseModel.__init__(self, db)
-        FlatBaseModel.__init__(self, db, search=search, skip=skip, scol=scol,
-                               order=order, sort_map=sort_map)
+        FlatBaseModel.__init__(
+            self,
+            db,
+            uistate,
+            search=search,
+            skip=skip,
+            scol=scol,
+            order=order,
+            sort_map=sort_map,
+        )
 
     def destroy(self):
         """
@@ -587,15 +613,33 @@ class PersonListModel(PeopleBaseModel, FlatBaseModel):
         PeopleBaseModel.destroy(self)
         FlatBaseModel.destroy(self)
 
+
 class PersonTreeModel(PeopleBaseModel, TreeBaseModel):
     """
     Hierarchical people model.
     """
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+
+    def __init__(
+        self,
+        db,
+        uistate,
+        scol=0,
+        order=Gtk.SortType.ASCENDING,
+        search=None,
+        skip=set(),
+        sort_map=None,
+    ):
         PeopleBaseModel.__init__(self, db)
-        TreeBaseModel.__init__(self, db, search=search, skip=skip, scol=scol,
-                               order=order, sort_map=sort_map)
+        TreeBaseModel.__init__(
+            self,
+            db,
+            uistate,
+            search=search,
+            skip=skip,
+            scol=scol,
+            order=order,
+            sort_map=sort_map,
+        )
 
     def destroy(self):
         """
@@ -606,19 +650,18 @@ class PersonTreeModel(PeopleBaseModel, TreeBaseModel):
         TreeBaseModel.destroy(self)
 
     def _set_base_data(self):
-        """See TreeBaseModel, we also set some extra lru caches
-        """
+        """See TreeBaseModel, we also set some extra lru caches"""
         self.number_items = self.db.get_number_of_people
 
     def get_tree_levels(self):
         """
         Return the headings of the levels in the hierarchy.
         """
-        return [_('Group As'), _('Name')]
+        return [_("Group As"), _("Name")]
 
     def column_header(self, node):
-        return node.name
-    
+        return node.name if node.name else no_surname
+
     def add_row(self, handle, data):
         """
         Add nodes to the node map for a single person.
@@ -627,17 +670,15 @@ class PersonTreeModel(PeopleBaseModel, TreeBaseModel):
         data        The object data.
         """
         ngn = name_displayer.name_grouping_data
-        
+
         name_data = data[COLUMN_NAME]
         group_name = ngn(self.db, name_data)
-        #if isinstance(group_name, str):
-        #    group_name = group_name.encode('utf-8')
         sort_key = self.sort_func(data)
 
-        #if group_name not in self.group_list:
-            #self.group_list.append(group_name)
-            #self.add_node(None, group_name, group_name, None)
-            
-        # add as node: parent, child, sortkey, handle; parent and child are 
+        # if group_name not in self.group_list:
+        # self.group_list.append(group_name)
+        # self.add_node(None, group_name, group_name, None)
+
+        # add as node: parent, child, sortkey, handle; parent and child are
         # nodes in the treebasemodel, and will be used as iters
         self.add_node(group_name, handle, sort_key, handle)
