@@ -22,33 +22,32 @@
 """
 
 from gramps.gen.plug.report import utils
-from gramps.gen.lib import ChildRefType
 
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Livrecurse base objects only
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class _PersonSeen:
-    """   librecurse base boject only
+    """librecurse base boject only
     Keep track of people that have been seen so we can call the correct
     virtual method.
     """
+
     def __init__(self):
         self.people_seen = set()
 
     def add_person(self, level, person_handle, family_handle):
-        """ a person is seen for the first time """
+        """a person is seen for the first time"""
         pass
 
     def add_person_again(self, level, person_handle, family_handle):
-        """ a person is seen again """
+        """a person is seen again"""
         pass
 
     def _add_person(self, level, person_handle, family_handle):
-        """ Which virtual method to call?
-        """
+        """Which virtual method to call?"""
         if person_handle is not None and person_handle in self.people_seen:
             self.add_person_again(level, person_handle, family_handle)
         else:
@@ -56,61 +55,65 @@ class _PersonSeen:
         if person_handle is not None:
             self.people_seen.add(person_handle)
 
+
 class _FamilySeen:
-    """   librecurse base boject only
+    """librecurse base boject only
     Keep track of the famalies that have been seen so we can call the correct
     virtual method.
     """
+
     def __init__(self):
         self.families_seen = set()
 
     def add_marriage(self, level, person_handle, family_handle):
-        """ Makes a marriage """
+        """Makes a marriage"""
         pass
 
     def add_marriage_again(self, level, person_handle, family_handle):
-        """ Makes a marriage """
+        """Makes a marriage"""
         pass
 
     def _add_marriage(self, level, person_handle, family_handle):
-        """ Makes a marriage """
+        """Makes a marriage"""
         if family_handle in self.families_seen:
             self.add_marriage_again(level, person_handle, family_handle)
         else:
             self.add_marriage(level, person_handle, family_handle)
         self.families_seen.add(family_handle)
 
+
 class _StopRecurse:
-    """ A simple class to break out the
-        . stop_recursion
-        . can_recurse
-        . continue_recursion
-        methods
+    """A simple class to break out the
+    . stop_recursion
+    . can_recurse
+    . continue_recursion
+    methods
     """
+
     def __init__(self):
         # The default value.  Lets recurse.
         self.__stop_recursion = False
 
     def stop_recursion(self):
-        """ Stop Recursion at theis person/family """
+        """Stop Recursion at theis person/family"""
         self.__stop_recursion = True
 
     def continue_recursion(self):
-        """ Used to allow recursion again """
+        """Used to allow recursion again"""
         self.__stop_recursion = False
 
     def can_recurse(self):
-        """ Has the upper class told up to stop or can we continue? """
-        return self.__stop_recursion == False
+        """Has the upper class told up to stop or can we continue?"""
+        return not self.__stop_recursion
 
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Class DescendPerson
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
-    """ Recursive (down) base class
+    """Recursive (down) base class
 
     The following methods need to be sub-classed as needed:
     . add_person
@@ -173,6 +176,7 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
     . mom (the spouse) is still shown even if s_level == 0
     . . father will have a level of (g_level,0), mother (g_level, 1)
     """
+
     def __init__(self, dbase, maxgen, maxspouse=0):
         _PersonSeen.__init__(self)
         _FamilySeen.__init__(self)
@@ -204,19 +208,19 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
         assert maxspouse >= 0
         self.max_spouses = maxspouse
 
-        #can we bold direct descendants?
-        #bold_now will have only three values
-        #0 - no bolding
-        #1 - Only bold the first person
-        #2 - Bold all direct descendants
+        # can we bold direct descendants?
+        # bold_now will have only three values
+        # 0 - no bolding
+        # 1 - Only bold the first person
+        # 2 - Bold all direct descendants
         self.__bold_now = 1
         self.__this_slevel = -1
 
     def is_direct_descendant(self):
-        """ Is this person a direct descendant?
-            . Can we bold this perosn and
-            . are they a direct child of the father/mother
-            . . not a spouse
+        """Is this person a direct descendant?
+        . Can we bold this perosn and
+        . are they a direct child of the father/mother
+        . . not a spouse
         """
         return self.__bold_now != 0 and self.__this_slevel == 0
 
@@ -233,7 +237,6 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
 
         for family_handle in person.get_family_handle_list():
             if family_handle not in self.families_seen:
-
                 family = self.database.get_family_from_handle(family_handle)
 
                 if family.get_child_ref_list():
@@ -253,7 +256,7 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
             return  # one generation too many
         if s_level > 0 and s_level == self.max_spouses:
             return
-        #if person_handle in self.people_seen: return
+        # if person_handle in self.people_seen: return
 
         person = self.database.get_person_from_handle(person_handle)
         family_handles = person.get_family_handle_list()
@@ -274,9 +277,8 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
             self.__bold_now = 0
 
         for family_handle in family_handles:
-            #Marriage box if the option is there.
-            self._add_marriage((g_level, s_level + 1),
-                                person_handle, family_handle)
+            # Marriage box if the option is there.
+            self._add_marriage((g_level, s_level + 1), person_handle, family_handle)
 
             if not self.can_recurse():
                 self.continue_recursion()
@@ -287,8 +289,7 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
             spouse_handle = utils.find_spouse(person, family)
             if self.max_spouses > s_level:
                 self.__this_slevel = s_level + 1
-                self._add_person((g_level, s_level + 1),
-                                  spouse_handle, family_handle)
+                self._add_person((g_level, s_level + 1), spouse_handle, family_handle)
 
                 if not self.can_recurse:
                     self.continue_recursion()
@@ -303,7 +304,7 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
                 self.continue_recursion()
 
             if self.max_spouses > s_level:
-                #spouse_handle = utils.find_spouse(person,family)
+                # spouse_handle = utils.find_spouse(person,family)
                 self.recurse(spouse_handle, g_level, s_level + 1)
 
         if s_level == 1:
@@ -326,12 +327,12 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
 
         self.__bold_now = 2
         self.__this_slevel = 0
-        #if father_h:
+        # if father_h:
         father_b = self._add_person((g_level, 0), father_h, family_handle)
-        #else:
+        # else:
         #    #TODO - should send family_h instead of None?
         #    father_b = self._add_person((g_level, 0), None, family_h)
-        #self.people_seen.add(father_h)
+        # self.people_seen.add(father_h)
 
         family_b = self._add_marriage((g_level, 1), father_h, family_handle)
 
@@ -360,7 +361,7 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
         if len(myfams) > 1:  # and self.max_spouses > 0
             show = True
 
-        #if self.max_spouses == 0 and not self.has_children(person_handle):
+        # if self.max_spouses == 0 and not self.has_children(person_handle):
         #    self.people_seen.add(person_handle)
         #    show = False
 
@@ -369,13 +370,13 @@ class DescendPerson(_StopRecurse, _PersonSeen, _FamilySeen):
             self.recurse(person_handle, g_level, 0)
 
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Class AscendPerson
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class AscendPerson(_StopRecurse, _PersonSeen):
-    """ Recursive (up) base class
+    """Recursive (up) base class
 
     The following methods need to be sub-classed as needed:
     . add_person
@@ -424,7 +425,7 @@ class AscendPerson(_StopRecurse, _PersonSeen):
         self.fill_out = maxfill
 
     def add_marriage(self, index, indi_handle, fams_handle):
-        """ Makes a marriage box and add that person into the Canvas. """
+        """Makes a marriage box and add that person into the Canvas."""
         # We are not using add_marriage only and not add_marriage_again
         # because the father will do any _again stuff if needed.
         pass
@@ -446,13 +447,13 @@ class AscendPerson(_StopRecurse, _PersonSeen):
         # Recursively call the function. It is okay if the handle is None,
         # since routine handles a handle of None
 
-        self.__fill(generation+1, index*2, mx_fill-1)
+        self.__fill(generation + 1, index * 2, mx_fill - 1)
         if mx_fill > 1:  # marriage of parents
-            self.add_marriage((generation+1, index*2), None, None)
+            self.add_marriage((generation + 1, index * 2), None, None)
             if not self.can_recurse():
                 self.continue_recursion()
                 return
-        self.__fill(generation+1, (index*2)+1, mx_fill-1)
+        self.__fill(generation + 1, (index * 2) + 1, mx_fill - 1)
 
     def __iterate(self, generation, index, person_handle, full_family_handle):
         """
@@ -485,8 +486,7 @@ class AscendPerson(_StopRecurse, _PersonSeen):
             self.continue_recursion()
             return
 
-
-        #Now recurse on the parents
+        # Now recurse on the parents
         family_handle = person.get_main_parents_family_handle()
 
         if family_handle is not None:
@@ -498,32 +498,41 @@ class AscendPerson(_StopRecurse, _PersonSeen):
             mother_handle = None
 
         # Recursively call the function. It is okay if the handle is None,
-        self.__iterate(generation+1, index*2, father_handle, family_handle)  #recurse on dad
+        self.__iterate(
+            generation + 1, index * 2, father_handle, family_handle
+        )  # recurse on dad
         if generation < self.max_generations:
             if father_handle is not None:  # Stil winin max_generations
-                self.add_marriage((generation+1, index*2), father_handle, family_handle)
+                self.add_marriage(
+                    (generation + 1, index * 2), father_handle, family_handle
+                )
             elif mother_handle is not None:
-                self.add_marriage((generation+1, index*2), mother_handle, family_handle)
+                self.add_marriage(
+                    (generation + 1, index * 2), mother_handle, family_handle
+                )
             elif family_handle is not None:
-                self.add_marriage((generation+1, index*2), None, family_handle)
+                self.add_marriage((generation + 1, index * 2), None, family_handle)
             elif self.fill_out > 0:
-                self.add_marriage((generation+1, index*2), None, None)
+                self.add_marriage((generation + 1, index * 2), None, None)
 
             if not self.can_recurse():
                 self.continue_recursion()
                 return
-        self.__iterate(generation+1, (index*2)+1, mother_handle, family_handle)  #recurse mom
+        self.__iterate(
+            generation + 1, (index * 2) + 1, mother_handle, family_handle
+        )  # recurse mom
 
     def recurse(self, person_handle):
         """
         A simple header to make sure we pass in the correct information
         """
         person = self.database.get_person_from_handle(person_handle)
-        return self.__iterate(1, 1, person_handle,
-                              person.get_main_parents_family_handle())
+        return self.__iterate(
+            1, 1, person_handle, person.get_main_parents_family_handle()
+        )
 
 
-#------------
+# ------------
 # Jer 29:11: "For I know the plans I have for you," declares the LORD,
 # "plans to prosper you and not to harm you, plans to give you hope
 # and a future."
